"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 213df39bd5e6

from __future__ import annotations
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FunctionResultEntryTypedDict(TypedDict):
    tool_call_id: str
    result: str
    object: Literal["entry"]
    type: Literal["function.result"]
    created_at: NotRequired[datetime]
    completed_at: NotRequired[Nullable[datetime]]
    id: NotRequired[str]


class FunctionResultEntry(BaseModel):
    tool_call_id: str

    result: str

    object: Annotated[
        Annotated[Optional[Literal["entry"]], AfterValidator(validate_const("entry"))],
        pydantic.Field(alias="object"),
    ] = "entry"

    type: Annotated[
        Annotated[
            Optional[Literal["function.result"]],
            AfterValidator(validate_const("function.result")),
        ],
        pydantic.Field(alias="type"),
    ] = "function.result"

    created_at: Optional[datetime] = None

    completed_at: OptionalNullable[datetime] = UNSET

    id: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["object", "type", "created_at", "completed_at", "id"])
        nullable_fields = set(["completed_at"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    FunctionResultEntry.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 19e3310c3907

from __future__ import annotations
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from mistralai.client.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AgentsAPIV1AgentsListVersionsRequestTypedDict(TypedDict):
    agent_id: str
    page: NotRequired[int]
    r"""Page number (0-indexed)"""
    page_size: NotRequired[int]
    r"""Number of versions per page"""


class AgentsAPIV1AgentsListVersionsRequest(BaseModel):
    agent_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 0
    r"""Page number (0-indexed)"""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 20
    r"""Number of versions per page"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["page", "page_size"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f7d790e84b65

from __future__ import annotations
from .embeddingresponsedata import EmbeddingResponseData, EmbeddingResponseDataTypedDict
from .usageinfo import UsageInfo, UsageInfoTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class EmbeddingResponseTypedDict(TypedDict):
    id: str
    object: str
    model: str
    usage: UsageInfoTypedDict
    data: List[EmbeddingResponseDataTypedDict]


class EmbeddingResponse(BaseModel):
    id: str

    object: str

    model: str

    usage: UsageInfo

    data: List[EmbeddingResponseData]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: cfbdde7fc0a2

from __future__ import annotations
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class JobMetadataTypedDict(TypedDict):
    expected_duration_seconds: NotRequired[Nullable[int]]
    cost: NotRequired[Nullable[float]]
    cost_currency: NotRequired[Nullable[str]]
    train_tokens_per_step: NotRequired[Nullable[int]]
    train_tokens: NotRequired[Nullable[int]]
    data_tokens: NotRequired[Nullable[int]]
    estimated_start_time: NotRequired[Nullable[int]]


class JobMetadata(BaseModel):
    expected_duration_seconds: OptionalNullable[int] = UNSET

    cost: OptionalNullable[float] = UNSET

    cost_currency: OptionalNullable[str] = UNSET

    train_tokens_per_step: OptionalNullable[int] = UNSET

    train_tokens: OptionalNullable[int] = UNSET

    data_tokens: OptionalNullable[int] = UNSET

    estimated_start_time: OptionalNullable[int] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "expected_duration_seconds",
                "cost",
                "cost_currency",
                "train_tokens_per_step",
                "train_tokens",
                "data_tokens",
                "estimated_start_time",
            ]
        )
        nullable_fields = set(
            [
                "expected_duration_seconds",
                "cost",
                "cost_currency",
                "train_tokens_per_step",
                "train_tokens",
                "data_tokens",
                "estimated_start_time",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 99d94c86a871

from __future__ import annotations
from .batchjob import BatchJob, BatchJobTypedDict
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListBatchJobsResponseTypedDict(TypedDict):
    total: int
    data: NotRequired[List[BatchJobTypedDict]]
    object: Literal["list"]


class ListBatchJobsResponse(BaseModel):
    total: int

    data: Optional[List[BatchJob]] = None

    object: Annotated[
        Annotated[Optional[Literal["list"]], AfterValidator(validate_const("list"))],
        pydantic.Field(alias="object"),
    ] = "list"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["data", "object"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    ListBatchJobsResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 681d90d50514

from __future__ import annotations
from .completionargs import CompletionArgs, CompletionArgsTypedDict
from .conversationinputs import ConversationInputs, ConversationInputsTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Any, Dict, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


ConversationRestartRequestHandoffExecution = Literal[
    "client",
    "server",
]


ConversationRestartRequestAgentVersionTypedDict = TypeAliasType(
    "ConversationRestartRequestAgentVersionTypedDict", Union[str, int]
)
r"""Specific version of the agent to use when restarting. If not provided, uses the current version."""


ConversationRestartRequestAgentVersion = TypeAliasType(
    "ConversationRestartRequestAgentVersion", Union[str, int]
)
r"""Specific version of the agent to use when restarting. If not provided, uses the current version."""


class ConversationRestartRequestTypedDict(TypedDict):
    r"""Request to restart a new conversation from a given entry in the conversation."""

    from_entry_id: str
    inputs: NotRequired[ConversationInputsTypedDict]
    stream: NotRequired[bool]
    store: NotRequired[bool]
    r"""Whether to store the results into our servers or not."""
    handoff_execution: NotRequired[ConversationRestartRequestHandoffExecution]
    completion_args: NotRequired[CompletionArgsTypedDict]
    r"""White-listed arguments from the completion API"""
    metadata: NotRequired[Nullable[Dict[str, Any]]]
    r"""Custom metadata for the conversation."""
    agent_version: NotRequired[
        Nullable[ConversationRestartRequestAgentVersionTypedDict]
    ]
    r"""Specific version of the agent to use when restarting. If not provided, uses the current version."""


class ConversationRestartRequest(BaseModel):
    r"""Request to restart a new conversation from a given entry in the conversation."""

    from_entry_id: str

    inputs: Optional[ConversationInputs] = None

    stream: Optional[bool] = False

    store: Optional[bool] = True
    r"""Whether to store the results into our servers or not."""

    handoff_execution: Optional[ConversationRestartRequestHandoffExecution] = "server"

    completion_args: Optional[CompletionArgs] = None
    r"""White-listed arguments from the completion API"""

    metadata: OptionalNullable[Dict[str, Any]] = UNSET
    r"""Custom metadata for the conversation."""

    agent_version: OptionalNullable[ConversationRestartRequestAgentVersion] = UNSET
    r"""Specific version of the agent to use when restarting. If not provided, uses the current version."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "inputs",
                "stream",
                "store",
                "handoff_execution",
                "completion_args",
                "metadata",
                "agent_version",
            ]
        )
        nullable_fields = set(["metadata", "agent_version"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: e0e8dad92725

from typing import Any, TYPE_CHECKING

from mistralai.client.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .agent import (
        Agent,
        AgentTool,
        AgentToolTypedDict,
        AgentTypedDict,
        UnknownAgentTool,
    )
    from .agentaliasresponse import AgentAliasResponse, AgentAliasResponseTypedDict
    from .agentconversation import (
        AgentConversation,
        AgentConversationAgentVersion,
        AgentConversationAgentVersionTypedDict,
        AgentConversationTypedDict,
    )
    from .agenthandoffdoneevent import (
        AgentHandoffDoneEvent,
        AgentHandoffDoneEventTypedDict,
    )
    from .agenthandoffentry import AgentHandoffEntry, AgentHandoffEntryTypedDict
    from .agenthandoffstartedevent import (
        AgentHandoffStartedEvent,
        AgentHandoffStartedEventTypedDict,
    )
    from .agents_api_v1_agents_create_or_update_aliasop import (
        AgentsAPIV1AgentsCreateOrUpdateAliasRequest,
        AgentsAPIV1AgentsCreateOrUpdateAliasRequestTypedDict,
    )
    from .agents_api_v1_agents_delete_aliasop import (
        AgentsAPIV1AgentsDeleteAliasRequest,
        AgentsAPIV1AgentsDeleteAliasRequestTypedDict,
    )
    from .agents_api_v1_agents_deleteop import (
        AgentsAPIV1AgentsDeleteRequest,
        AgentsAPIV1AgentsDeleteRequestTypedDict,
    )
    from .agents_api_v1_agents_get_versionop import (
        AgentsAPIV1AgentsGetVersionRequest,
        AgentsAPIV1AgentsGetVersionRequestTypedDict,
    )
    from .agents_api_v1_agents_getop import (
        AgentsAPIV1AgentsGetAgentVersion,
        AgentsAPIV1AgentsGetAgentVersionTypedDict,
        AgentsAPIV1AgentsGetRequest,
        AgentsAPIV1AgentsGetRequestTypedDict,
    )
    from .agents_api_v1_agents_list_version_aliasesop import (
        AgentsAPIV1AgentsListVersionAliasesRequest,
        AgentsAPIV1AgentsListVersionAliasesRequestTypedDict,
    )
    from .agents_api_v1_agents_list_versionsop import (
        AgentsAPIV1AgentsListVersionsRequest,
        AgentsAPIV1AgentsListVersionsRequestTypedDict,
    )
    from .agents_api_v1_agents_listop import (
        AgentsAPIV1AgentsListRequest,
        AgentsAPIV1AgentsListRequestTypedDict,
    )
    from .agents_api_v1_agents_update_versionop import (
        AgentsAPIV1AgentsUpdateVersionRequest,
        AgentsAPIV1AgentsUpdateVersionRequestTypedDict,
    )
    from .agents_api_v1_agents_updateop import (
        AgentsAPIV1AgentsUpdateRequest,
        AgentsAPIV1AgentsUpdateRequestTypedDict,
    )
    from .agents_api_v1_conversations_append_streamop import (
        AgentsAPIV1ConversationsAppendStreamRequest,
        AgentsAPIV1ConversationsAppendStreamRequestTypedDict,
    )
    from .agents_api_v1_conversations_appendop import (
        AgentsAPIV1ConversationsAppendRequest,
        AgentsAPIV1ConversationsAppendRequestTypedDict,
    )
    from .agents_api_v1_conversations_deleteop import (
        AgentsAPIV1ConversationsDeleteRequest,
        AgentsAPIV1ConversationsDeleteRequestTypedDict,
    )
    from .agents_api_v1_conversations_getop import (
        AgentsAPIV1ConversationsGetRequest,
        AgentsAPIV1ConversationsGetRequestTypedDict,
        ResponseV1ConversationsGet,
        ResponseV1ConversationsGetTypedDict,
    )
    from .agents_api_v1_conversations_historyop import (
        AgentsAPIV1ConversationsHistoryRequest,
        AgentsAPIV1ConversationsHistoryRequestTypedDict,
    )
    from .agents_api_v1_conversations_listop import (
        AgentsAPIV1ConversationsListRequest,
        AgentsAPIV1ConversationsListRequestTypedDict,
        AgentsAPIV1ConversationsListResponse,
        AgentsAPIV1ConversationsListResponseTypedDict,
    )
    from .agents_api_v1_conversations_messagesop import (
        AgentsAPIV1ConversationsMessagesRequest,
        AgentsAPIV1ConversationsMessagesRequestTypedDict,
    )
    from .agents_api_v1_conversations_restart_streamop import (
        AgentsAPIV1ConversationsRestartStreamRequest,
        AgentsAPIV1ConversationsRestartStreamRequestTypedDict,
    )
    from .agents_api_v1_conversations_restartop import (
        AgentsAPIV1ConversationsRestartRequest,
        AgentsAPIV1ConversationsRestartRequestTypedDict,
    )
    from .agentscompletionrequest import (
        AgentsCompletionRequest,
        AgentsCompletionRequestMessage,
        AgentsCompletionRequestMessageTypedDict,
        AgentsCompletionRequestStop,
        AgentsCompletionRequestStopTypedDict,
        AgentsCompletionRequestToolChoice,
        AgentsCompletionRequestToolChoiceTypedDict,
        AgentsCompletionRequestTypedDict,
    )
    from .agentscompletionstreamrequest import (
        AgentsCompletionStreamRequest,
        AgentsCompletionStreamRequestMessage,
        AgentsCompletionStreamRequestMessageTypedDict,
        AgentsCompletionStreamRequestStop,
        AgentsCompletionStreamRequestStopTypedDict,
        AgentsCompletionStreamRequestToolChoice,
        AgentsCompletionStreamRequestToolChoiceTypedDict,
        AgentsCompletionStreamRequestTypedDict,
    )
    from .apiendpoint import APIEndpoint
    from .archivemodelresponse import (
        ArchiveModelResponse,
        ArchiveModelResponseTypedDict,
    )
    from .assistantmessage import (
        AssistantMessage,
        AssistantMessageContent,
        AssistantMessageContentTypedDict,
        AssistantMessageTypedDict,
    )
    from .audiochunk import AudioChunk, AudioChunkTypedDict
    from .audioencoding import AudioEncoding
    from .audioformat import AudioFormat, AudioFormatTypedDict
    from .audiotranscriptionrequest import (
        AudioTranscriptionRequest,
        AudioTranscriptionRequestTypedDict,
    )
    from .audiotranscriptionrequeststream import (
        AudioTranscriptionRequestStream,
        AudioTranscriptionRequestStreamTypedDict,
    )
    from .basemodelcard import BaseModelCard, BaseModelCardTypedDict
    from .batcherror import BatchError, BatchErrorTypedDict
    from .batchjob import BatchJob, BatchJobTypedDict
    from .batchjobstatus import BatchJobStatus
    from .batchrequest import BatchRequest, BatchRequestTypedDict
    from .builtinconnectors import BuiltInConnectors
    from .chatclassificationrequest import (
        ChatClassificationRequest,
        ChatClassificationRequestTypedDict,
    )
    from .chatcompletionchoice import (
        ChatCompletionChoice,
        ChatCompletionChoiceFinishReason,
        ChatCompletionChoiceTypedDict,
    )
    from .chatcompletionrequest import (
        ChatCompletionRequest,
        ChatCompletionRequestMessage,
        ChatCompletionRequestMessageTypedDict,
        ChatCompletionRequestStop,
        ChatCompletionRequestStopTypedDict,
        ChatCompletionRequestToolChoice,
        ChatCompletionRequestToolChoiceTypedDict,
        ChatCompletionRequestTypedDict,
    )
    from .chatcompletionresponse import (
        ChatCompletionResponse,
        ChatCompletionResponseTypedDict,
    )
    from .chatcompletionstreamrequest import (
        ChatCompletionStreamRequest,
        ChatCompletionStreamRequestMessage,
        ChatCompletionStreamRequestMessageTypedDict,
        ChatCompletionStreamRequestStop,
        ChatCompletionStreamRequestStopTypedDict,
        ChatCompletionStreamRequestToolChoice,
        ChatCompletionStreamRequestToolChoiceTypedDict,
        ChatCompletionStreamRequestTypedDict,
    )
    from .chatmoderationrequest import (
        ChatModerationRequest,
        ChatModerationRequestInputs1,
        ChatModerationRequestInputs1TypedDict,
        ChatModerationRequestInputs2,
        ChatModerationRequestInputs2TypedDict,
        ChatModerationRequestInputs3,
        ChatModerationRequestInputs3TypedDict,
        ChatModerationRequestTypedDict,
    )
    from .checkpoint import Checkpoint, CheckpointTypedDict
    from .classificationrequest import (
        ClassificationRequest,
        ClassificationRequestInputs,
        ClassificationRequestInputsTypedDict,
        ClassificationRequestTypedDict,
    )
    from .classificationresponse import (
        ClassificationResponse,
        ClassificationResponseTypedDict,
    )
    from .classificationtargetresult import (
        ClassificationTargetResult,
        ClassificationTargetResultTypedDict,
    )
    from .classifierfinetunedmodel import (
        ClassifierFineTunedModel,
        ClassifierFineTunedModelTypedDict,
    )
    from .classifierfinetuningjob import (
        ClassifierFineTuningJob,
        ClassifierFineTuningJobIntegration,
        ClassifierFineTuningJobIntegrationTypedDict,
        ClassifierFineTuningJobStatus,
        ClassifierFineTuningJobTypedDict,
        UnknownClassifierFineTuningJobIntegration,
    )
    from .classifierfinetuningjobdetails import (
        ClassifierFineTuningJobDetails,
        ClassifierFineTuningJobDetailsIntegration,
        ClassifierFineTuningJobDetailsIntegrationTypedDict,
        ClassifierFineTuningJobDetailsStatus,
        ClassifierFineTuningJobDetailsTypedDict,
        UnknownClassifierFineTuningJobDetailsIntegration,
    )
    from .classifiertarget import ClassifierTarget, ClassifierTargetTypedDict
    from .classifiertargetresult import (
        ClassifierTargetResult,
        ClassifierTargetResultTypedDict,
    )
    from .classifiertrainingparameters import (
        ClassifierTrainingParameters,
        ClassifierTrainingParametersTypedDict,
    )
    from .codeinterpretertool import CodeInterpreterTool, CodeInterpreterToolTypedDict
    from .completionargs import CompletionArgs, CompletionArgsTypedDict
    from .completionargsstop import CompletionArgsStop, CompletionArgsStopTypedDict
    from .completionchunk import CompletionChunk, CompletionChunkTypedDict
    from .completionevent import CompletionEvent, CompletionEventTypedDict
    from .completionfinetunedmodel import (
        CompletionFineTunedModel,
        CompletionFineTunedModelTypedDict,
    )
    from .completionfinetuningjob import (
        CompletionFineTuningJob,
        CompletionFineTuningJobIntegration,
        CompletionFineTuningJobIntegrationTypedDict,
        CompletionFineTuningJobRepository,
        CompletionFineTuningJobRepositoryTypedDict,
        CompletionFineTuningJobStatus,
        CompletionFineTuningJobTypedDict,
        UnknownCompletionFineTuningJobIntegration,
        UnknownCompletionFineTuningJobRepository,
    )
    from .completionfinetuningjobdetails import (
        CompletionFineTuningJobDetails,
        CompletionFineTuningJobDetailsIntegration,
        CompletionFineTuningJobDetailsIntegrationTypedDict,
        CompletionFineTuningJobDetailsRepository,
        CompletionFineTuningJobDetailsRepositoryTypedDict,
        CompletionFineTuningJobDetailsStatus,
        CompletionFineTuningJobDetailsTypedDict,
        UnknownCompletionFineTuningJobDetailsIntegration,
        UnknownCompletionFineTuningJobDetailsRepository,
    )
    from .completionresponsestreamchoice import (
        CompletionResponseStreamChoice,
        CompletionResponseStreamChoiceFinishReason,
        CompletionResponseStreamChoiceTypedDict,
    )
    from .completiontrainingparameters import (
        CompletionTrainingParameters,
        CompletionTrainingParametersTypedDict,
    )
    from .contentchunk import ContentChunk, ContentChunkTypedDict, UnknownContentChunk
    from .conversationappendrequest import (
        ConversationAppendRequest,
        ConversationAppendRequestHandoffExecution,
        ConversationAppendRequestTypedDict,
    )
    from .conversationappendstreamrequest import (
        ConversationAppendStreamRequest,
        ConversationAppendStreamRequestHandoffExecution,
        ConversationAppendStreamRequestTypedDict,
    )
    from .conversationevents import (
        ConversationEvents,
        ConversationEventsData,
        ConversationEventsDataTypedDict,
        ConversationEventsTypedDict,
        UnknownConversationEventsData,
    )
    from .conversationhistory import (
        ConversationHistory,
        ConversationHistoryTypedDict,
        Entry,
        EntryTypedDict,
    )
    from .conversationinputs import ConversationInputs, ConversationInputsTypedDict
    from .conversationmessages import (
        ConversationMessages,
        ConversationMessagesTypedDict,
    )
    from .conversationrequest import (
        ConversationRequest,
        ConversationRequestAgentVersion,
        ConversationRequestAgentVersionTypedDict,
        ConversationRequestHandoffExecution,
        ConversationRequestTool,
        ConversationRequestToolTypedDict,
        ConversationRequestTypedDict,
    )
    from .conversationresponse import (
        ConversationResponse,
        ConversationResponseTypedDict,
        Output,
        OutputTypedDict,
    )
    from .conversationrestartrequest import (
        ConversationRestartRequest,
        ConversationRestartRequestAgentVersion,
        ConversationRestartRequestAgentVersionTypedDict,
        ConversationRestartRequestHandoffExecution,
        ConversationRestartRequestTypedDict,
    )
    from .conversationrestartstreamrequest import (
        ConversationRestartStreamRequest,
        ConversationRestartStreamRequestAgentVersion,
        ConversationRestartStreamRequestAgentVersionTypedDict,
        ConversationRestartStreamRequestHandoffExecution,
        ConversationRestartStreamRequestTypedDict,
    )
    from .conversationstreamrequest import (
        ConversationStreamRequest,
        ConversationStreamRequestAgentVersion,
        ConversationStreamRequestAgentVersionTypedDict,
        ConversationStreamRequestHandoffExecution,
        ConversationStreamRequestTool,
        ConversationStreamRequestToolTypedDict,
        ConversationStreamRequestTypedDict,
    )
    from .conversationthinkchunk import (
        ConversationThinkChunk,
        ConversationThinkChunkThinking,
        ConversationThinkChunkThinkingTypedDict,
        ConversationThinkChunkTypedDict,
    )
    from .conversationusageinfo import (
        ConversationUsageInfo,
        ConversationUsageInfoTypedDict,
    )
    from .createagentrequest import (
        CreateAgentRequest,
        CreateAgentRequestTool,
        CreateAgentRequestToolTypedDict,
        CreateAgentRequestTypedDict,
    )
    from .createbatchjobrequest import (
        CreateBatchJobRequest,
        CreateBatchJobRequestTypedDict,
    )
    from .createfileresponse import CreateFileResponse, CreateFileResponseTypedDict
    from .createfinetuningjobrequest import (
        CreateFineTuningJobRequest,
        CreateFineTuningJobRequestIntegration,
        CreateFineTuningJobRequestIntegrationTypedDict,
        CreateFineTuningJobRequestRepository,
        CreateFineTuningJobRequestRepositoryTypedDict,
        CreateFineTuningJobRequestTypedDict,
        Hyperparameters,
        HyperparametersTypedDict,
    )
    from .createlibraryrequest import (
        CreateLibraryRequest,
        CreateLibraryRequestTypedDict,
    )
    from .delete_model_v1_models_model_id_deleteop import (
        DeleteModelV1ModelsModelIDDeleteRequest,
        DeleteModelV1ModelsModelIDDeleteRequestTypedDict,
    )
    from .deletefileresponse import DeleteFileResponse, DeleteFileResponseTypedDict
    from .deletemodelout import DeleteModelOut, DeleteModelOutTypedDict
    from .deltamessage import (
        DeltaMessage,
        DeltaMessageContent,
        DeltaMessageContentTypedDict,
        DeltaMessageTypedDict,
    )
    from .document import Document, DocumentTypedDict
    from .documentlibrarytool import DocumentLibraryTool, DocumentLibraryToolTypedDict
    from .documenttextcontent import DocumentTextContent, DocumentTextContentTypedDict
    from .documenturlchunk import DocumentURLChunk, DocumentURLChunkTypedDict
    from .embeddingdtype import EmbeddingDtype
    from .embeddingrequest import (
        EmbeddingRequest,
        EmbeddingRequestInputs,
        EmbeddingRequestInputsTypedDict,
        EmbeddingRequestTypedDict,
    )
    from .embeddingresponse import EmbeddingResponse, EmbeddingResponseTypedDict
    from .embeddingresponsedata import (
        EmbeddingResponseData,
        EmbeddingResponseDataTypedDict,
    )
    from .encodingformat import EncodingFormat
    from .entitytype import EntityType
    from .event import Event, EventTypedDict
    from .file import File, FileTypedDict
    from .filechunk import FileChunk, FileChunkTypedDict
    from .filepurpose import FilePurpose
    from .files_api_routes_delete_fileop import (
        FilesAPIRoutesDeleteFileRequest,
        FilesAPIRoutesDeleteFileRequestTypedDict,
    )
    from .files_api_routes_download_fileop import (
        FilesAPIRoutesDownloadFileRequest,
        FilesAPIRoutesDownloadFileRequestTypedDict,
    )
    from .files_api_routes_get_signed_urlop import (
        FilesAPIRoutesGetSignedURLRequest,
        FilesAPIRoutesGetSignedURLRequestTypedDict,
    )
    from .files_api_routes_list_filesop import (
        FilesAPIRoutesListFilesRequest,
        FilesAPIRoutesListFilesRequestTypedDict,
    )
    from .files_api_routes_retrieve_fileop import (
        FilesAPIRoutesRetrieveFileRequest,
        FilesAPIRoutesRetrieveFileRequestTypedDict,
    )
    from .files_api_routes_upload_fileop import (
        MultiPartBodyParams,
        MultiPartBodyParamsTypedDict,
    )
    from .fileschema import FileSchema, FileSchemaTypedDict
    from .fimcompletionrequest import (
        FIMCompletionRequest,
        FIMCompletionRequestStop,
        FIMCompletionRequestStopTypedDict,
        FIMCompletionRequestTypedDict,
    )
    from .fimcompletionresponse import (
        FIMCompletionResponse,
        FIMCompletionResponseTypedDict,
    )
    from .fimcompletionstreamrequest import (
        FIMCompletionStreamRequest,
        FIMCompletionStreamRequestStop,
        FIMCompletionStreamRequestStopTypedDict,
        FIMCompletionStreamRequestTypedDict,
    )
    from .finetuneablemodeltype import FineTuneableModelType
    from .finetunedmodelcapabilities import (
        FineTunedModelCapabilities,
        FineTunedModelCapabilitiesTypedDict,
    )
    from .ftclassifierlossfunction import FTClassifierLossFunction
    from .ftmodelcard import FTModelCard, FTModelCardTypedDict
    from .function import Function, FunctionTypedDict
    from .functioncall import (
        Arguments,
        ArgumentsTypedDict,
        FunctionCall,
        FunctionCallTypedDict,
    )
    from .functioncallentry import (
        FunctionCallEntry,
        FunctionCallEntryConfirmationStatus,
        FunctionCallEntryTypedDict,
    )
    from .functioncallentryarguments import (
        FunctionCallEntryArguments,
        FunctionCallEntryArgumentsTypedDict,
    )
    from .functioncallevent import (
        FunctionCallEvent,
        FunctionCallEventConfirmationStatus,
        FunctionCallEventTypedDict,
    )
    from .functionname import FunctionName, FunctionNameTypedDict
    from .functionresultentry import FunctionResultEntry, FunctionResultEntryTypedDict
    from .functiontool import FunctionTool, FunctionToolTypedDict
    from .getfileresponse import GetFileResponse, GetFileResponseTypedDict
    from .getsignedurlresponse import (
        GetSignedURLResponse,
        GetSignedURLResponseTypedDict,
    )
    from .githubrepository import GithubRepository, GithubRepositoryTypedDict
    from .githubrepositoryin import GithubRepositoryIn, GithubRepositoryInTypedDict
    from .imagedetail import ImageDetail
    from .imagegenerationtool import ImageGenerationTool, ImageGenerationToolTypedDict
    from .imageurl import ImageURL, ImageURLTypedDict
    from .imageurlchunk import (
        ImageURLChunk,
        ImageURLChunkTypedDict,
        ImageURLUnion,
        ImageURLUnionTypedDict,
    )
    from .inputentries import InputEntries, InputEntriesTypedDict
    from .inputs import Inputs, InputsTypedDict
    from .instructrequest import (
        InstructRequest,
        InstructRequestMessage,
        InstructRequestMessageTypedDict,
        InstructRequestTypedDict,
    )
    from .jobmetadata import JobMetadata, JobMetadataTypedDict
    from .jobs_api_routes_batch_cancel_batch_jobop import (
        JobsAPIRoutesBatchCancelBatchJobRequest,
        JobsAPIRoutesBatchCancelBatchJobRequestTypedDict,
    )
    from .jobs_api_routes_batch_get_batch_jobop import (
        JobsAPIRoutesBatchGetBatchJobRequest,
        JobsAPIRoutesBatchGetBatchJobRequestTypedDict,
    )
    from .jobs_api_routes_batch_get_batch_jobsop import (
        JobsAPIRoutesBatchGetBatchJobsRequest,
        JobsAPIRoutesBatchGetBatchJobsRequestTypedDict,
        OrderBy,
    )
    from .jobs_api_routes_fine_tuning_archive_fine_tuned_modelop import (
        JobsAPIRoutesFineTuningArchiveFineTunedModelRequest,
        JobsAPIRoutesFineTuningArchiveFineTunedModelRequestTypedDict,
    )
    from .jobs_api_routes_fine_tuning_cancel_fine_tuning_jobop import (
        JobsAPIRoutesFineTuningCancelFineTuningJobRequest,
        JobsAPIRoutesFineTuningCancelFineTuningJobRequestTypedDict,
        JobsAPIRoutesFineTuningCancelFineTuningJobResponse,
        JobsAPIRoutesFineTuningCancelFineTuningJobResponseTypedDict,
        UnknownJobsAPIRoutesFineTuningCancelFineTuningJobResponse,
    )
    from .jobs_api_routes_fine_tuning_create_fine_tuning_jobop import (
        JobsAPIRoutesFineTuningCreateFineTuningJobResponse,
        JobsAPIRoutesFineTuningCreateFineTuningJobResponseTypedDict,
        Response,
        ResponseTypedDict,
        UnknownResponse,
    )
    from .jobs_api_routes_fine_tuning_get_fine_tuning_jobop import (
        JobsAPIRoutesFineTuningGetFineTuningJobRequest,
        JobsAPIRoutesFineTuningGetFineTuningJobRequestTypedDict,
        JobsAPIRoutesFineTuningGetFineTuningJobResponse,
        JobsAPIRoutesFineTuningGetFineTuningJobResponseTypedDict,
        UnknownJobsAPIRoutesFineTuningGetFineTuningJobResponse,
    )
    from .jobs_api_routes_fine_tuning_get_fine_tuning_jobsop import (
        JobsAPIRoutesFineTuningGetFineTuningJobsRequest,
        JobsAPIRoutesFineTuningGetFineTuningJobsRequestTypedDict,
        JobsAPIRoutesFineTuningGetFineTuningJobsStatus,
    )
    from .jobs_api_routes_fine_tuning_start_fine_tuning_jobop import (
        JobsAPIRoutesFineTuningStartFineTuningJobRequest,
        JobsAPIRoutesFineTuningStartFineTuningJobRequestTypedDict,
        JobsAPIRoutesFineTuningStartFineTuningJobResponse,
        JobsAPIRoutesFineTuningStartFineTuningJobResponseTypedDict,
        UnknownJobsAPIRoutesFineTuningStartFineTuningJobResponse,
    )
    from .jobs_api_routes_fine_tuning_unarchive_fine_tuned_modelop import (
        JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequest,
        JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequestTypedDict,
    )
    from .jobs_api_routes_fine_tuning_update_fine_tuned_modelop import (
        JobsAPIRoutesFineTuningUpdateFineTunedModelRequest,
        JobsAPIRoutesFineTuningUpdateFineTunedModelRequestTypedDict,
        JobsAPIRoutesFineTuningUpdateFineTunedModelResponse,
        JobsAPIRoutesFineTuningUpdateFineTunedModelResponseTypedDict,
        UnknownJobsAPIRoutesFineTuningUpdateFineTunedModelResponse,
    )
    from .jsonschema import JSONSchema, JSONSchemaTypedDict
    from .legacyjobmetadata import LegacyJobMetadata, LegacyJobMetadataTypedDict
    from .libraries_delete_v1op import (
        LibrariesDeleteV1Request,
        LibrariesDeleteV1RequestTypedDict,
    )
    from .libraries_documents_delete_v1op import (
        LibrariesDocumentsDeleteV1Request,
        LibrariesDocumentsDeleteV1RequestTypedDict,
    )
    from .libraries_documents_get_extracted_text_signed_url_v1op import (
        LibrariesDocumentsGetExtractedTextSignedURLV1Request,
        LibrariesDocumentsGetExtractedTextSignedURLV1RequestTypedDict,
    )
    from .libraries_documents_get_signed_url_v1op import (
        LibrariesDocumentsGetSignedURLV1Request,
        LibrariesDocumentsGetSignedURLV1RequestTypedDict,
    )
    from .libraries_documents_get_status_v1op import (
        LibrariesDocumentsGetStatusV1Request,
        LibrariesDocumentsGetStatusV1RequestTypedDict,
    )
    from .libraries_documents_get_text_content_v1op import (
        LibrariesDocumentsGetTextContentV1Request,
        LibrariesDocumentsGetTextContentV1RequestTypedDict,
    )
    from .libraries_documents_get_v1op import (
        LibrariesDocumentsGetV1Request,
        LibrariesDocumentsGetV1RequestTypedDict,
    )
    from .libraries_documents_list_v1op import (
        LibrariesDocumentsListV1Request,
        LibrariesDocumentsListV1RequestTypedDict,
    )
    from .libraries_documents_reprocess_v1op import (
        LibrariesDocumentsReprocessV1Request,
        LibrariesDocumentsReprocessV1RequestTypedDict,
    )
    from .libraries_documents_update_v1op import (
        LibrariesDocumentsUpdateV1Request,
        LibrariesDocumentsUpdateV1RequestTypedDict,
    )
    from .libraries_documents_upload_v1op import (
        DocumentUpload,
        DocumentUploadTypedDict,
        LibrariesDocumentsUploadV1Request,
        LibrariesDocumentsUploadV1RequestTypedDict,
    )
    from .libraries_get_v1op import (
        LibrariesGetV1Request,
        LibrariesGetV1RequestTypedDict,
    )
    from .libraries_share_create_v1op import (
        LibrariesShareCreateV1Request,
        LibrariesShareCreateV1RequestTypedDict,
    )
    from .libraries_share_delete_v1op import (
        LibrariesShareDeleteV1Request,
        LibrariesShareDeleteV1RequestTypedDict,
    )
    from .libraries_share_list_v1op import (
        LibrariesShareListV1Request,
        LibrariesShareListV1RequestTypedDict,
    )
    from .libraries_update_v1op import (
        LibrariesUpdateV1Request,
        LibrariesUpdateV1RequestTypedDict,
    )
    from .library import Library, LibraryTypedDict
    from .listbatchjobsresponse import (
        ListBatchJobsResponse,
        ListBatchJobsResponseTypedDict,
    )
    from .listdocumentsresponse import (
        ListDocumentsResponse,
        ListDocumentsResponseTypedDict,
    )
    from .listfilesresponse import ListFilesResponse, ListFilesResponseTypedDict
    from .listfinetuningjobsresponse import (
        ListFineTuningJobsResponse,
        ListFineTuningJobsResponseData,
        ListFineTuningJobsResponseDataTypedDict,
        ListFineTuningJobsResponseTypedDict,
        UnknownListFineTuningJobsResponseData,
    )
    from .listlibrariesresponse import (
        ListLibrariesResponse,
        ListLibrariesResponseTypedDict,
    )
    from .listsharingout import ListSharingOut, ListSharingOutTypedDict
    from .messageentries import MessageEntries, MessageEntriesTypedDict
    from .messageinputcontentchunks import (
        MessageInputContentChunks,
        MessageInputContentChunksTypedDict,
    )
    from .messageinputentry import (
        MessageInputEntry,
        MessageInputEntryContent,
        MessageInputEntryContentTypedDict,
        MessageInputEntryTypedDict,
        Role,
    )
    from .messageoutputcontentchunks import (
        MessageOutputContentChunks,
        MessageOutputContentChunksTypedDict,
    )
    from .messageoutputentry import (
        MessageOutputEntry,
        MessageOutputEntryContent,
        MessageOutputEntryContentTypedDict,
        MessageOutputEntryTypedDict,
    )
    from .messageoutputevent import (
        MessageOutputEvent,
        MessageOutputEventContent,
        MessageOutputEventContentTypedDict,
        MessageOutputEventTypedDict,
    )
    from .metric import Metric, MetricTypedDict
    from .mistralpromptmode import MistralPromptMode
    from .modelcapabilities import ModelCapabilities, ModelCapabilitiesTypedDict
    from .modelconversation import (
        ModelConversation,
        ModelConversationTool,
        ModelConversationToolTypedDict,
        ModelConversationTypedDict,
        UnknownModelConversationTool,
    )
    from .modellist import (
        ModelList,
        ModelListData,
        ModelListDataTypedDict,
        ModelListTypedDict,
        UnknownModelListData,
    )
    from .moderationobject import ModerationObject, ModerationObjectTypedDict
    from .moderationresponse import ModerationResponse, ModerationResponseTypedDict
    from .ocrimageobject import OCRImageObject, OCRImageObjectTypedDict
    from .ocrpagedimensions import OCRPageDimensions, OCRPageDimensionsTypedDict
    from .ocrpageobject import OCRPageObject, OCRPageObjectTypedDict
    from .ocrrequest import (
        DocumentUnion,
        DocumentUnionTypedDict,
        OCRRequest,
        OCRRequestTypedDict,
        TableFormat,
    )
    from .ocrresponse import OCRResponse, OCRResponseTypedDict
    from .ocrtableobject import Format, OCRTableObject, OCRTableObjectTypedDict
    from .ocrusageinfo import OCRUsageInfo, OCRUsageInfoTypedDict
    from .outputcontentchunks import OutputContentChunks, OutputContentChunksTypedDict
    from .paginationinfo import PaginationInfo, PaginationInfoTypedDict
    from .prediction import Prediction, PredictionTypedDict
    from .processingstatusout import ProcessingStatusOut, ProcessingStatusOutTypedDict
    from .realtimetranscriptionerror import (
        RealtimeTranscriptionError,
        RealtimeTranscriptionErrorTypedDict,
    )
    from .realtimetranscriptionerrordetail import (
        RealtimeTranscriptionErrorDetail,
        RealtimeTranscriptionErrorDetailMessage,
        RealtimeTranscriptionErrorDetailMessageTypedDict,
        RealtimeTranscriptionErrorDetailTypedDict,
    )
    from .realtimetranscriptioninputaudioappend import (
        RealtimeTranscriptionInputAudioAppend,
        RealtimeTranscriptionInputAudioAppendTypedDict,
    )
    from .realtimetranscriptioninputaudioend import (
        RealtimeTranscriptionInputAudioEnd,
        RealtimeTranscriptionInputAudioEndTypedDict,
    )
    from .realtimetranscriptioninputaudioflush import (
        RealtimeTranscriptionInputAudioFlush,
        RealtimeTranscriptionInputAudioFlushTypedDict,
    )
    from .realtimetranscriptionsession import (
        RealtimeTranscriptionSession,
        RealtimeTranscriptionSessionTypedDict,
    )
    from .realtimetranscriptionsessioncreated import (
        RealtimeTranscriptionSessionCreated,
        RealtimeTranscriptionSessionCreatedTypedDict,
    )
    from .realtimetranscriptionsessionupdated import (
        RealtimeTranscriptionSessionUpdated,
        RealtimeTranscriptionSessionUpdatedTypedDict,
    )
    from .realtimetranscriptionsessionupdatemessage import (
        RealtimeTranscriptionSessionUpdateMessage,
        RealtimeTranscriptionSessionUpdateMessageTypedDict,
    )
    from .realtimetranscriptionsessionupdatepayload import (
        RealtimeTranscriptionSessionUpdatePayload,
        RealtimeTranscriptionSessionUpdatePayloadTypedDict,
    )
    from .referencechunk import ReferenceChunk, ReferenceChunkTypedDict
    from .requestsource import RequestSource
    from .responsedoneevent import ResponseDoneEvent, ResponseDoneEventTypedDict
    from .responseerrorevent import ResponseErrorEvent, ResponseErrorEventTypedDict
    from .responseformat import ResponseFormat, ResponseFormatTypedDict
    from .responseformats import ResponseFormats
    from .responsestartedevent import (
        ResponseStartedEvent,
        ResponseStartedEventTypedDict,
    )
    from .retrieve_model_v1_models_model_id_getop import (
        ResponseRetrieveModelV1ModelsModelIDGet,
        ResponseRetrieveModelV1ModelsModelIDGetTypedDict,
        RetrieveModelV1ModelsModelIDGetRequest,
        RetrieveModelV1ModelsModelIDGetRequestTypedDict,
        UnknownResponseRetrieveModelV1ModelsModelIDGet,
    )
    from .sampletype import SampleType
    from .security import Security, SecurityTypedDict
    from .shareenum import ShareEnum
    from .sharingdelete import SharingDelete, SharingDeleteTypedDict
    from .sharingin import SharingIn, SharingInTypedDict
    from .sharingout import SharingOut, SharingOutTypedDict
    from .source import Source
    from .ssetypes import SSETypes
    from .systemmessage import (
        SystemMessage,
        SystemMessageContent,
        SystemMessageContentTypedDict,
        SystemMessageTypedDict,
    )
    from .systemmessagecontentchunks import (
        SystemMessageContentChunks,
        SystemMessageContentChunksTypedDict,
    )
    from .textchunk import TextChunk, TextChunkTypedDict
    from .thinkchunk import (
        ThinkChunk,
        ThinkChunkThinking,
        ThinkChunkThinkingTypedDict,
        ThinkChunkTypedDict,
    )
    from .timestampgranularity import TimestampGranularity
    from .tool import Tool, ToolTypedDict
    from .toolcall import ToolCall, ToolCallTypedDict
    from .toolcallconfirmation import (
        Confirmation,
        ToolCallConfirmation,
        ToolCallConfirmationTypedDict,
    )
    from .toolchoice import ToolChoice, ToolChoiceTypedDict
    from .toolchoiceenum import ToolChoiceEnum
    from .toolconfiguration import ToolConfiguration, ToolConfigurationTypedDict
    from .toolexecutiondeltaevent import (
        ToolExecutionDeltaEvent,
        ToolExecutionDeltaEventName,
        ToolExecutionDeltaEventNameTypedDict,
        ToolExecutionDeltaEventTypedDict,
    )
    from .toolexecutiondoneevent import (
        ToolExecutionDoneEvent,
        ToolExecutionDoneEventName,
        ToolExecutionDoneEventNameTypedDict,
        ToolExecutionDoneEventTypedDict,
    )
    from .toolexecutionentry import (
        ToolExecutionEntry,
        ToolExecutionEntryName,
        ToolExecutionEntryNameTypedDict,
        ToolExecutionEntryTypedDict,
    )
    from .toolexecutionstartedevent import (
        ToolExecutionStartedEvent,
        ToolExecutionStartedEventName,
        ToolExecutionStartedEventNameTypedDict,
        ToolExecutionStartedEventTypedDict,
    )
    from .toolfilechunk import (
        ToolFileChunk,
        ToolFileChunkTool,
        ToolFileChunkToolTypedDict,
        ToolFileChunkTypedDict,
    )
    from .toolmessage import (
        ToolMessage,
        ToolMessageContent,
        ToolMessageContentTypedDict,
        ToolMessageTypedDict,
    )
    from .toolreferencechunk import (
        ToolReferenceChunk,
        ToolReferenceChunkTool,
        ToolReferenceChunkToolTypedDict,
        ToolReferenceChunkTypedDict,
    )
    from .tooltypes import ToolTypes
    from .trainingfile import TrainingFile, TrainingFileTypedDict
    from .transcriptionresponse import (
        TranscriptionResponse,
        TranscriptionResponseTypedDict,
    )
    from .transcriptionsegmentchunk import (
        TranscriptionSegmentChunk,
        TranscriptionSegmentChunkTypedDict,
    )
    from .transcriptionstreamdone import (
        TranscriptionStreamDone,
        TranscriptionStreamDoneTypedDict,
    )
    from .transcriptionstreamevents import (
        TranscriptionStreamEvents,
        TranscriptionStreamEventsData,
        TranscriptionStreamEventsDataTypedDict,
        TranscriptionStreamEventsTypedDict,
        UnknownTranscriptionStreamEventsData,
    )
    from .transcriptionstreameventtypes import TranscriptionStreamEventTypes
    from .transcriptionstreamlanguage import (
        TranscriptionStreamLanguage,
        TranscriptionStreamLanguageTypedDict,
    )
    from .transcriptionstreamsegmentdelta import (
        TranscriptionStreamSegmentDelta,
        TranscriptionStreamSegmentDeltaTypedDict,
    )
    from .transcriptionstreamtextdelta import (
        TranscriptionStreamTextDelta,
        TranscriptionStreamTextDeltaTypedDict,
    )
    from .unarchivemodelresponse import (
        UnarchiveModelResponse,
        UnarchiveModelResponseTypedDict,
    )
    from .updateagentrequest import (
        UpdateAgentRequest,
        UpdateAgentRequestTool,
        UpdateAgentRequestToolTypedDict,
        UpdateAgentRequestTypedDict,
    )
    from .updatedocumentrequest import (
        Attributes,
        AttributesTypedDict,
        UpdateDocumentRequest,
        UpdateDocumentRequestTypedDict,
    )
    from .updatelibraryrequest import (
        UpdateLibraryRequest,
        UpdateLibraryRequestTypedDict,
    )
    from .updatemodelrequest import UpdateModelRequest, UpdateModelRequestTypedDict
    from .usageinfo import UsageInfo, UsageInfoTypedDict
    from .usermessage import (
        UserMessage,
        UserMessageContent,
        UserMessageContentTypedDict,
        UserMessageTypedDict,
    )
    from .validationerror import (
        Loc,
        LocTypedDict,
        ValidationError,
        ValidationErrorTypedDict,
    )
    from .wandbintegration import WandbIntegration, WandbIntegrationTypedDict
    from .wandbintegrationresult import (
        WandbIntegrationResult,
        WandbIntegrationResultTypedDict,
    )
    from .websearchpremiumtool import (
        WebSearchPremiumTool,
        WebSearchPremiumToolTypedDict,
    )
    from .websearchtool import WebSearchTool, WebSearchToolTypedDict

__all__ = [
    "APIEndpoint",
    "Agent",
    "AgentAliasResponse",
    "AgentAliasResponseTypedDict",
    "AgentConversation",
    "AgentConversationAgentVersion",
    "AgentConversationAgentVersionTypedDict",
    "AgentConversationTypedDict",
    "AgentHandoffDoneEvent",
    "AgentHandoffDoneEventTypedDict",
    "AgentHandoffEntry",
    "AgentHandoffEntryTypedDict",
    "AgentHandoffStartedEvent",
    "AgentHandoffStartedEventTypedDict",
    "AgentTool",
    "AgentToolTypedDict",
    "AgentTypedDict",
    "AgentsAPIV1AgentsCreateOrUpdateAliasRequest",
    "AgentsAPIV1AgentsCreateOrUpdateAliasRequestTypedDict",
    "AgentsAPIV1AgentsDeleteAliasRequest",
    "AgentsAPIV1AgentsDeleteAliasRequestTypedDict",
    "AgentsAPIV1AgentsDeleteRequest",
    "AgentsAPIV1AgentsDeleteRequestTypedDict",
    "AgentsAPIV1AgentsGetAgentVersion",
    "AgentsAPIV1AgentsGetAgentVersionTypedDict",
    "AgentsAPIV1AgentsGetRequest",
    "AgentsAPIV1AgentsGetRequestTypedDict",
    "AgentsAPIV1AgentsGetVersionRequest",
    "AgentsAPIV1AgentsGetVersionRequestTypedDict",
    "AgentsAPIV1AgentsListRequest",
    "AgentsAPIV1AgentsListRequestTypedDict",
    "AgentsAPIV1AgentsListVersionAliasesRequest",
    "AgentsAPIV1AgentsListVersionAliasesRequestTypedDict",
    "AgentsAPIV1AgentsListVersionsRequest",
    "AgentsAPIV1AgentsListVersionsRequestTypedDict",
    "AgentsAPIV1AgentsUpdateRequest",
    "AgentsAPIV1AgentsUpdateRequestTypedDict",
    "AgentsAPIV1AgentsUpdateVersionRequest",
    "AgentsAPIV1AgentsUpdateVersionRequestTypedDict",
    "AgentsAPIV1ConversationsAppendRequest",
    "AgentsAPIV1ConversationsAppendRequestTypedDict",
    "AgentsAPIV1ConversationsAppendStreamRequest",
    "AgentsAPIV1ConversationsAppendStreamRequestTypedDict",
    "AgentsAPIV1ConversationsDeleteRequest",
    "AgentsAPIV1ConversationsDeleteRequestTypedDict",
    "AgentsAPIV1ConversationsGetRequest",
    "AgentsAPIV1ConversationsGetRequestTypedDict",
    "AgentsAPIV1ConversationsHistoryRequest",
    "AgentsAPIV1ConversationsHistoryRequestTypedDict",
    "AgentsAPIV1ConversationsListRequest",
    "AgentsAPIV1ConversationsListRequestTypedDict",
    "AgentsAPIV1ConversationsListResponse",
    "AgentsAPIV1ConversationsListResponseTypedDict",
    "AgentsAPIV1ConversationsMessagesRequest",
    "AgentsAPIV1ConversationsMessagesRequestTypedDict",
    "AgentsAPIV1ConversationsRestartRequest",
    "AgentsAPIV1ConversationsRestartRequestTypedDict",
    "AgentsAPIV1ConversationsRestartStreamRequest",
    "AgentsAPIV1ConversationsRestartStreamRequestTypedDict",
    "AgentsCompletionRequest",
    "AgentsCompletionRequestMessage",
    "AgentsCompletionRequestMessageTypedDict",
    "AgentsCompletionRequestStop",
    "AgentsCompletionRequestStopTypedDict",
    "AgentsCompletionRequestToolChoice",
    "AgentsCompletionRequestToolChoiceTypedDict",
    "AgentsCompletionRequestTypedDict",
    "AgentsCompletionStreamRequest",
    "AgentsCompletionStreamRequestMessage",
    "AgentsCompletionStreamRequestMessageTypedDict",
    "AgentsCompletionStreamRequestStop",
    "AgentsCompletionStreamRequestStopTypedDict",
    "AgentsCompletionStreamRequestToolChoice",
    "AgentsCompletionStreamRequestToolChoiceTypedDict",
    "AgentsCompletionStreamRequestTypedDict",
    "ArchiveModelResponse",
    "ArchiveModelResponseTypedDict",
    "Arguments",
    "ArgumentsTypedDict",
    "AssistantMessage",
    "AssistantMessageContent",
    "AssistantMessageContentTypedDict",
    "AssistantMessageTypedDict",
    "Attributes",
    "AttributesTypedDict",
    "AudioChunk",
    "AudioChunkTypedDict",
    "AudioEncoding",
    "AudioFormat",
    "AudioFormatTypedDict",
    "AudioTranscriptionRequest",
    "AudioTranscriptionRequestStream",
    "AudioTranscriptionRequestStreamTypedDict",
    "AudioTranscriptionRequestTypedDict",
    "BaseModelCard",
    "BaseModelCardTypedDict",
    "BatchError",
    "BatchErrorTypedDict",
    "BatchJob",
    "BatchJobStatus",
    "BatchJobTypedDict",
    "BatchRequest",
    "BatchRequestTypedDict",
    "BuiltInConnectors",
    "ChatClassificationRequest",
    "ChatClassificationRequestTypedDict",
    "ChatCompletionChoice",
    "ChatCompletionChoiceFinishReason",
    "ChatCompletionChoiceTypedDict",
    "ChatCompletionRequest",
    "ChatCompletionRequestMessage",
    "ChatCompletionRequestMessageTypedDict",
    "ChatCompletionRequestStop",
    "ChatCompletionRequestStopTypedDict",
    "ChatCompletionRequestToolChoice",
    "ChatCompletionRequestToolChoiceTypedDict",
    "ChatCompletionRequestTypedDict",
    "ChatCompletionResponse",
    "ChatCompletionResponseTypedDict",
    "ChatCompletionStreamRequest",
    "ChatCompletionStreamRequestMessage",
    "ChatCompletionStreamRequestMessageTypedDict",
    "ChatCompletionStreamRequestStop",
    "ChatCompletionStreamRequestStopTypedDict",
    "ChatCompletionStreamRequestToolChoice",
    "ChatCompletionStreamRequestToolChoiceTypedDict",
    "ChatCompletionStreamRequestTypedDict",
    "ChatModerationRequest",
    "ChatModerationRequestInputs1",
    "ChatModerationRequestInputs1TypedDict",
    "ChatModerationRequestInputs2",
    "ChatModerationRequestInputs2TypedDict",
    "ChatModerationRequestInputs3",
    "ChatModerationRequestInputs3TypedDict",
    "ChatModerationRequestTypedDict",
    "Checkpoint",
    "CheckpointTypedDict",
    "ClassificationRequest",
    "ClassificationRequestInputs",
    "ClassificationRequestInputsTypedDict",
    "ClassificationRequestTypedDict",
    "ClassificationResponse",
    "ClassificationResponseTypedDict",
    "ClassificationTargetResult",
    "ClassificationTargetResultTypedDict",
    "ClassifierFineTunedModel",
    "ClassifierFineTunedModelTypedDict",
    "ClassifierFineTuningJob",
    "ClassifierFineTuningJobDetails",
    "ClassifierFineTuningJobDetailsIntegration",
    "ClassifierFineTuningJobDetailsIntegrationTypedDict",
    "ClassifierFineTuningJobDetailsStatus",
    "ClassifierFineTuningJobDetailsTypedDict",
    "ClassifierFineTuningJobIntegration",
    "ClassifierFineTuningJobIntegrationTypedDict",
    "ClassifierFineTuningJobStatus",
    "ClassifierFineTuningJobTypedDict",
    "ClassifierTarget",
    "ClassifierTargetResult",
    "ClassifierTargetResultTypedDict",
    "ClassifierTargetTypedDict",
    "ClassifierTrainingParameters",
    "ClassifierTrainingParametersTypedDict",
    "CodeInterpreterTool",
    "CodeInterpreterToolTypedDict",
    "CompletionArgs",
    "CompletionArgsStop",
    "CompletionArgsStopTypedDict",
    "CompletionArgsTypedDict",
    "CompletionChunk",
    "CompletionChunkTypedDict",
    "CompletionEvent",
    "CompletionEventTypedDict",
    "CompletionFineTunedModel",
    "CompletionFineTunedModelTypedDict",
    "CompletionFineTuningJob",
    "CompletionFineTuningJobDetails",
    "CompletionFineTuningJobDetailsIntegration",
    "CompletionFineTuningJobDetailsIntegrationTypedDict",
    "CompletionFineTuningJobDetailsRepository",
    "CompletionFineTuningJobDetailsRepositoryTypedDict",
    "CompletionFineTuningJobDetailsStatus",
    "CompletionFineTuningJobDetailsTypedDict",
    "CompletionFineTuningJobIntegration",
    "CompletionFineTuningJobIntegrationTypedDict",
    "CompletionFineTuningJobRepository",
    "CompletionFineTuningJobRepositoryTypedDict",
    "CompletionFineTuningJobStatus",
    "CompletionFineTuningJobTypedDict",
    "CompletionResponseStreamChoice",
    "CompletionResponseStreamChoiceFinishReason",
    "CompletionResponseStreamChoiceTypedDict",
    "CompletionTrainingParameters",
    "CompletionTrainingParametersTypedDict",
    "Confirmation",
    "ContentChunk",
    "ContentChunkTypedDict",
    "ConversationAppendRequest",
    "ConversationAppendRequestHandoffExecution",
    "ConversationAppendRequestTypedDict",
    "ConversationAppendStreamRequest",
    "ConversationAppendStreamRequestHandoffExecution",
    "ConversationAppendStreamRequestTypedDict",
    "ConversationEvents",
    "ConversationEventsData",
    "ConversationEventsDataTypedDict",
    "ConversationEventsTypedDict",
    "ConversationHistory",
    "ConversationHistoryTypedDict",
    "ConversationInputs",
    "ConversationInputsTypedDict",
    "ConversationMessages",
    "ConversationMessagesTypedDict",
    "ConversationRequest",
    "ConversationRequestAgentVersion",
    "ConversationRequestAgentVersionTypedDict",
    "ConversationRequestHandoffExecution",
    "ConversationRequestTool",
    "ConversationRequestToolTypedDict",
    "ConversationRequestTypedDict",
    "ConversationResponse",
    "ConversationResponseTypedDict",
    "ConversationRestartRequest",
    "ConversationRestartRequestAgentVersion",
    "ConversationRestartRequestAgentVersionTypedDict",
    "ConversationRestartRequestHandoffExecution",
    "ConversationRestartRequestTypedDict",
    "ConversationRestartStreamRequest",
    "ConversationRestartStreamRequestAgentVersion",
    "ConversationRestartStreamRequestAgentVersionTypedDict",
    "ConversationRestartStreamRequestHandoffExecution",
    "ConversationRestartStreamRequestTypedDict",
    "ConversationStreamRequest",
    "ConversationStreamRequestAgentVersion",
    "ConversationStreamRequestAgentVersionTypedDict",
    "ConversationStreamRequestHandoffExecution",
    "ConversationStreamRequestTool",
    "ConversationStreamRequestToolTypedDict",
    "ConversationStreamRequestTypedDict",
    "ConversationThinkChunk",
    "ConversationThinkChunkThinking",
    "ConversationThinkChunkThinkingTypedDict",
    "ConversationThinkChunkTypedDict",
    "ConversationUsageInfo",
    "ConversationUsageInfoTypedDict",
    "CreateAgentRequest",
    "CreateAgentRequestTool",
    "CreateAgentRequestToolTypedDict",
    "CreateAgentRequestTypedDict",
    "CreateBatchJobRequest",
    "CreateBatchJobRequestTypedDict",
    "CreateFileResponse",
    "CreateFileResponseTypedDict",
    "CreateFineTuningJobRequest",
    "CreateFineTuningJobRequestIntegration",
    "CreateFineTuningJobRequestIntegrationTypedDict",
    "CreateFineTuningJobRequestRepository",
    "CreateFineTuningJobRequestRepositoryTypedDict",
    "CreateFineTuningJobRequestTypedDict",
    "CreateLibraryRequest",
    "CreateLibraryRequestTypedDict",
    "DeleteFileResponse",
    "DeleteFileResponseTypedDict",
    "DeleteModelOut",
    "DeleteModelOutTypedDict",
    "DeleteModelV1ModelsModelIDDeleteRequest",
    "DeleteModelV1ModelsModelIDDeleteRequestTypedDict",
    "DeltaMessage",
    "DeltaMessageContent",
    "DeltaMessageContentTypedDict",
    "DeltaMessageTypedDict",
    "Document",
    "DocumentLibraryTool",
    "DocumentLibraryToolTypedDict",
    "DocumentTextContent",
    "DocumentTextContentTypedDict",
    "DocumentTypedDict",
    "DocumentURLChunk",
    "DocumentURLChunkTypedDict",
    "DocumentUnion",
    "DocumentUnionTypedDict",
    "DocumentUpload",
    "DocumentUploadTypedDict",
    "EmbeddingDtype",
    "EmbeddingRequest",
    "EmbeddingRequestInputs",
    "EmbeddingRequestInputsTypedDict",
    "EmbeddingRequestTypedDict",
    "EmbeddingResponse",
    "EmbeddingResponseData",
    "EmbeddingResponseDataTypedDict",
    "EmbeddingResponseTypedDict",
    "EncodingFormat",
    "EntityType",
    "Entry",
    "EntryTypedDict",
    "Event",
    "EventTypedDict",
    "FIMCompletionRequest",
    "FIMCompletionRequestStop",
    "FIMCompletionRequestStopTypedDict",
    "FIMCompletionRequestTypedDict",
    "FIMCompletionResponse",
    "FIMCompletionResponseTypedDict",
    "FIMCompletionStreamRequest",
    "FIMCompletionStreamRequestStop",
    "FIMCompletionStreamRequestStopTypedDict",
    "FIMCompletionStreamRequestTypedDict",
    "FTClassifierLossFunction",
    "FTModelCard",
    "FTModelCardTypedDict",
    "File",
    "FileChunk",
    "FileChunkTypedDict",
    "FilePurpose",
    "FileSchema",
    "FileSchemaTypedDict",
    "FileTypedDict",
    "FilesAPIRoutesDeleteFileRequest",
    "FilesAPIRoutesDeleteFileRequestTypedDict",
    "FilesAPIRoutesDownloadFileRequest",
    "FilesAPIRoutesDownloadFileRequestTypedDict",
    "FilesAPIRoutesGetSignedURLRequest",
    "FilesAPIRoutesGetSignedURLRequestTypedDict",
    "FilesAPIRoutesListFilesRequest",
    "FilesAPIRoutesListFilesRequestTypedDict",
    "FilesAPIRoutesRetrieveFileRequest",
    "FilesAPIRoutesRetrieveFileRequestTypedDict",
    "FineTuneableModelType",
    "FineTunedModelCapabilities",
    "FineTunedModelCapabilitiesTypedDict",
    "Format",
    "Function",
    "FunctionCall",
    "FunctionCallEntry",
    "FunctionCallEntryArguments",
    "FunctionCallEntryArgumentsTypedDict",
    "FunctionCallEntryConfirmationStatus",
    "FunctionCallEntryTypedDict",
    "FunctionCallEvent",
    "FunctionCallEventConfirmationStatus",
    "FunctionCallEventTypedDict",
    "FunctionCallTypedDict",
    "FunctionName",
    "FunctionNameTypedDict",
    "FunctionResultEntry",
    "FunctionResultEntryTypedDict",
    "FunctionTool",
    "FunctionToolTypedDict",
    "FunctionTypedDict",
    "GetFileResponse",
    "GetFileResponseTypedDict",
    "GetSignedURLResponse",
    "GetSignedURLResponseTypedDict",
    "GithubRepository",
    "GithubRepositoryIn",
    "GithubRepositoryInTypedDict",
    "GithubRepositoryTypedDict",
    "Hyperparameters",
    "HyperparametersTypedDict",
    "ImageDetail",
    "ImageGenerationTool",
    "ImageGenerationToolTypedDict",
    "ImageURL",
    "ImageURLChunk",
    "ImageURLChunkTypedDict",
    "ImageURLTypedDict",
    "ImageURLUnion",
    "ImageURLUnionTypedDict",
    "InputEntries",
    "InputEntriesTypedDict",
    "Inputs",
    "InputsTypedDict",
    "InstructRequest",
    "InstructRequestMessage",
    "InstructRequestMessageTypedDict",
    "InstructRequestTypedDict",
    "JSONSchema",
    "JSONSchemaTypedDict",
    "JobMetadata",
    "JobMetadataTypedDict",
    "JobsAPIRoutesBatchCancelBatchJobRequest",
    "JobsAPIRoutesBatchCancelBatchJobRequestTypedDict",
    "JobsAPIRoutesBatchGetBatchJobRequest",
    "JobsAPIRoutesBatchGetBatchJobRequestTypedDict",
    "JobsAPIRoutesBatchGetBatchJobsRequest",
    "JobsAPIRoutesBatchGetBatchJobsRequestTypedDict",
    "JobsAPIRoutesFineTuningArchiveFineTunedModelRequest",
    "JobsAPIRoutesFineTuningArchiveFineTunedModelRequestTypedDict",
    "JobsAPIRoutesFineTuningCancelFineTuningJobRequest",
    "JobsAPIRoutesFineTuningCancelFineTuningJobRequestTypedDict",
    "JobsAPIRoutesFineTuningCancelFineTuningJobResponse",
    "JobsAPIRoutesFineTuningCancelFineTuningJobResponseTypedDict",
    "JobsAPIRoutesFineTuningCreateFineTuningJobResponse",
    "JobsAPIRoutesFineTuningCreateFineTuningJobResponseTypedDict",
    "JobsAPIRoutesFineTuningGetFineTuningJobRequest",
    "JobsAPIRoutesFineTuningGetFineTuningJobRequestTypedDict",
    "JobsAPIRoutesFineTuningGetFineTuningJobResponse",
    "JobsAPIRoutesFineTuningGetFineTuningJobResponseTypedDict",
    "JobsAPIRoutesFineTuningGetFineTuningJobsRequest",
    "JobsAPIRoutesFineTuningGetFineTuningJobsRequestTypedDict",
    "JobsAPIRoutesFineTuningGetFineTuningJobsStatus",
    "JobsAPIRoutesFineTuningStartFineTuningJobRequest",
    "JobsAPIRoutesFineTuningStartFineTuningJobRequestTypedDict",
    "JobsAPIRoutesFineTuningStartFineTuningJobResponse",
    "JobsAPIRoutesFineTuningStartFineTuningJobResponseTypedDict",
    "JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequest",
    "JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequestTypedDict",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelRequest",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelRequestTypedDict",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelResponse",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelResponseTypedDict",
    "LegacyJobMetadata",
    "LegacyJobMetadataTypedDict",
    "LibrariesDeleteV1Request",
    "LibrariesDeleteV1RequestTypedDict",
    "LibrariesDocumentsDeleteV1Request",
    "LibrariesDocumentsDeleteV1RequestTypedDict",
    "LibrariesDocumentsGetExtractedTextSignedURLV1Request",
    "LibrariesDocumentsGetExtractedTextSignedURLV1RequestTypedDict",
    "LibrariesDocumentsGetSignedURLV1Request",
    "LibrariesDocumentsGetSignedURLV1RequestTypedDict",
    "LibrariesDocumentsGetStatusV1Request",
    "LibrariesDocumentsGetStatusV1RequestTypedDict",
    "LibrariesDocumentsGetTextContentV1Request",
    "LibrariesDocumentsGetTextContentV1RequestTypedDict",
    "LibrariesDocumentsGetV1Request",
    "LibrariesDocumentsGetV1RequestTypedDict",
    "LibrariesDocumentsListV1Request",
    "LibrariesDocumentsListV1RequestTypedDict",
    "LibrariesDocumentsReprocessV1Request",
    "LibrariesDocumentsReprocessV1RequestTypedDict",
    "LibrariesDocumentsUpdateV1Request",
    "LibrariesDocumentsUpdateV1RequestTypedDict",
    "LibrariesDocumentsUploadV1Request",
    "LibrariesDocumentsUploadV1RequestTypedDict",
    "LibrariesGetV1Request",
    "LibrariesGetV1RequestTypedDict",
    "LibrariesShareCreateV1Request",
    "LibrariesShareCreateV1RequestTypedDict",
    "LibrariesShareDeleteV1Request",
    "LibrariesShareDeleteV1RequestTypedDict",
    "LibrariesShareListV1Request",
    "LibrariesShareListV1RequestTypedDict",
    "LibrariesUpdateV1Request",
    "LibrariesUpdateV1RequestTypedDict",
    "Library",
    "LibraryTypedDict",
    "ListBatchJobsResponse",
    "ListBatchJobsResponseTypedDict",
    "ListDocumentsResponse",
    "ListDocumentsResponseTypedDict",
    "ListFilesResponse",
    "ListFilesResponseTypedDict",
    "ListFineTuningJobsResponse",
    "ListFineTuningJobsResponseData",
    "ListFineTuningJobsResponseDataTypedDict",
    "ListFineTuningJobsResponseTypedDict",
    "ListLibrariesResponse",
    "ListLibrariesResponseTypedDict",
    "ListSharingOut",
    "ListSharingOutTypedDict",
    "Loc",
    "LocTypedDict",
    "MessageEntries",
    "MessageEntriesTypedDict",
    "MessageInputContentChunks",
    "MessageInputContentChunksTypedDict",
    "MessageInputEntry",
    "MessageInputEntryContent",
    "MessageInputEntryContentTypedDict",
    "MessageInputEntryTypedDict",
    "MessageOutputContentChunks",
    "MessageOutputContentChunksTypedDict",
    "MessageOutputEntry",
    "MessageOutputEntryContent",
    "MessageOutputEntryContentTypedDict",
    "MessageOutputEntryTypedDict",
    "MessageOutputEvent",
    "MessageOutputEventContent",
    "MessageOutputEventContentTypedDict",
    "MessageOutputEventTypedDict",
    "Metric",
    "MetricTypedDict",
    "MistralPromptMode",
    "ModelCapabilities",
    "ModelCapabilitiesTypedDict",
    "ModelConversation",
    "ModelConversationTool",
    "ModelConversationToolTypedDict",
    "ModelConversationTypedDict",
    "ModelList",
    "ModelListData",
    "ModelListDataTypedDict",
    "ModelListTypedDict",
    "ModerationObject",
    "ModerationObjectTypedDict",
    "ModerationResponse",
    "ModerationResponseTypedDict",
    "MultiPartBodyParams",
    "MultiPartBodyParamsTypedDict",
    "OCRImageObject",
    "OCRImageObjectTypedDict",
    "OCRPageDimensions",
    "OCRPageDimensionsTypedDict",
    "OCRPageObject",
    "OCRPageObjectTypedDict",
    "OCRRequest",
    "OCRRequestTypedDict",
    "OCRResponse",
    "OCRResponseTypedDict",
    "OCRTableObject",
    "OCRTableObjectTypedDict",
    "OCRUsageInfo",
    "OCRUsageInfoTypedDict",
    "OrderBy",
    "Output",
    "OutputContentChunks",
    "OutputContentChunksTypedDict",
    "OutputTypedDict",
    "PaginationInfo",
    "PaginationInfoTypedDict",
    "Prediction",
    "PredictionTypedDict",
    "ProcessingStatusOut",
    "ProcessingStatusOutTypedDict",
    "RealtimeTranscriptionError",
    "RealtimeTranscriptionErrorDetail",
    "RealtimeTranscriptionErrorDetailMessage",
    "RealtimeTranscriptionErrorDetailMessageTypedDict",
    "RealtimeTranscriptionErrorDetailTypedDict",
    "RealtimeTranscriptionErrorTypedDict",
    "RealtimeTranscriptionInputAudioAppend",
    "RealtimeTranscriptionInputAudioAppendTypedDict",
    "RealtimeTranscriptionInputAudioEnd",
    "RealtimeTranscriptionInputAudioEndTypedDict",
    "RealtimeTranscriptionInputAudioFlush",
    "RealtimeTranscriptionInputAudioFlushTypedDict",
    "RealtimeTranscriptionSession",
    "RealtimeTranscriptionSessionCreated",
    "RealtimeTranscriptionSessionCreatedTypedDict",
    "RealtimeTranscriptionSessionTypedDict",
    "RealtimeTranscriptionSessionUpdateMessage",
    "RealtimeTranscriptionSessionUpdateMessageTypedDict",
    "RealtimeTranscriptionSessionUpdatePayload",
    "RealtimeTranscriptionSessionUpdatePayloadTypedDict",
    "RealtimeTranscriptionSessionUpdated",
    "RealtimeTranscriptionSessionUpdatedTypedDict",
    "ReferenceChunk",
    "ReferenceChunkTypedDict",
    "RequestSource",
    "Response",
    "ResponseDoneEvent",
    "ResponseDoneEventTypedDict",
    "ResponseErrorEvent",
    "ResponseErrorEventTypedDict",
    "ResponseFormat",
    "ResponseFormatTypedDict",
    "ResponseFormats",
    "ResponseRetrieveModelV1ModelsModelIDGet",
    "ResponseRetrieveModelV1ModelsModelIDGetTypedDict",
    "ResponseStartedEvent",
    "ResponseStartedEventTypedDict",
    "ResponseTypedDict",
    "ResponseV1ConversationsGet",
    "ResponseV1ConversationsGetTypedDict",
    "RetrieveModelV1ModelsModelIDGetRequest",
    "RetrieveModelV1ModelsModelIDGetRequestTypedDict",
    "Role",
    "SSETypes",
    "SampleType",
    "Security",
    "SecurityTypedDict",
    "ShareEnum",
    "SharingDelete",
    "SharingDeleteTypedDict",
    "SharingIn",
    "SharingInTypedDict",
    "SharingOut",
    "SharingOutTypedDict",
    "Source",
    "SystemMessage",
    "SystemMessageContent",
    "SystemMessageContentChunks",
    "SystemMessageContentChunksTypedDict",
    "SystemMessageContentTypedDict",
    "SystemMessageTypedDict",
    "TableFormat",
    "TextChunk",
    "TextChunkTypedDict",
    "ThinkChunk",
    "ThinkChunkThinking",
    "ThinkChunkThinkingTypedDict",
    "ThinkChunkTypedDict",
    "TimestampGranularity",
    "Tool",
    "ToolCall",
    "ToolCallConfirmation",
    "ToolCallConfirmationTypedDict",
    "ToolCallTypedDict",
    "ToolChoice",
    "ToolChoiceEnum",
    "ToolChoiceTypedDict",
    "ToolConfiguration",
    "ToolConfigurationTypedDict",
    "ToolExecutionDeltaEvent",
    "ToolExecutionDeltaEventName",
    "ToolExecutionDeltaEventNameTypedDict",
    "ToolExecutionDeltaEventTypedDict",
    "ToolExecutionDoneEvent",
    "ToolExecutionDoneEventName",
    "ToolExecutionDoneEventNameTypedDict",
    "ToolExecutionDoneEventTypedDict",
    "ToolExecutionEntry",
    "ToolExecutionEntryName",
    "ToolExecutionEntryNameTypedDict",
    "ToolExecutionEntryTypedDict",
    "ToolExecutionStartedEvent",
    "ToolExecutionStartedEventName",
    "ToolExecutionStartedEventNameTypedDict",
    "ToolExecutionStartedEventTypedDict",
    "ToolFileChunk",
    "ToolFileChunkTool",
    "ToolFileChunkToolTypedDict",
    "ToolFileChunkTypedDict",
    "ToolMessage",
    "ToolMessageContent",
    "ToolMessageContentTypedDict",
    "ToolMessageTypedDict",
    "ToolReferenceChunk",
    "ToolReferenceChunkTool",
    "ToolReferenceChunkToolTypedDict",
    "ToolReferenceChunkTypedDict",
    "ToolTypedDict",
    "ToolTypes",
    "TrainingFile",
    "TrainingFileTypedDict",
    "TranscriptionResponse",
    "TranscriptionResponseTypedDict",
    "TranscriptionSegmentChunk",
    "TranscriptionSegmentChunkTypedDict",
    "TranscriptionStreamDone",
    "TranscriptionStreamDoneTypedDict",
    "TranscriptionStreamEventTypes",
    "TranscriptionStreamEvents",
    "TranscriptionStreamEventsData",
    "TranscriptionStreamEventsDataTypedDict",
    "TranscriptionStreamEventsTypedDict",
    "TranscriptionStreamLanguage",
    "TranscriptionStreamLanguageTypedDict",
    "TranscriptionStreamSegmentDelta",
    "TranscriptionStreamSegmentDeltaTypedDict",
    "TranscriptionStreamTextDelta",
    "TranscriptionStreamTextDeltaTypedDict",
    "UnarchiveModelResponse",
    "UnarchiveModelResponseTypedDict",
    "UnknownAgentTool",
    "UnknownClassifierFineTuningJobDetailsIntegration",
    "UnknownClassifierFineTuningJobIntegration",
    "UnknownCompletionFineTuningJobDetailsIntegration",
    "UnknownCompletionFineTuningJobDetailsRepository",
    "UnknownCompletionFineTuningJobIntegration",
    "UnknownCompletionFineTuningJobRepository",
    "UnknownContentChunk",
    "UnknownConversationEventsData",
    "UnknownJobsAPIRoutesFineTuningCancelFineTuningJobResponse",
    "UnknownJobsAPIRoutesFineTuningGetFineTuningJobResponse",
    "UnknownJobsAPIRoutesFineTuningStartFineTuningJobResponse",
    "UnknownJobsAPIRoutesFineTuningUpdateFineTunedModelResponse",
    "UnknownListFineTuningJobsResponseData",
    "UnknownModelConversationTool",
    "UnknownModelListData",
    "UnknownResponse",
    "UnknownResponseRetrieveModelV1ModelsModelIDGet",
    "UnknownTranscriptionStreamEventsData",
    "UpdateAgentRequest",
    "UpdateAgentRequestTool",
    "UpdateAgentRequestToolTypedDict",
    "UpdateAgentRequestTypedDict",
    "UpdateDocumentRequest",
    "UpdateDocumentRequestTypedDict",
    "UpdateLibraryRequest",
    "UpdateLibraryRequestTypedDict",
    "UpdateModelRequest",
    "UpdateModelRequestTypedDict",
    "UsageInfo",
    "UsageInfoTypedDict",
    "UserMessage",
    "UserMessageContent",
    "UserMessageContentTypedDict",
    "UserMessageTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "WandbIntegration",
    "WandbIntegrationResult",
    "WandbIntegrationResultTypedDict",
    "WandbIntegrationTypedDict",
    "WebSearchPremiumTool",
    "WebSearchPremiumToolTypedDict",
    "WebSearchTool",
    "WebSearchToolTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "Agent": ".agent",
    "AgentTool": ".agent",
    "AgentToolTypedDict": ".agent",
    "AgentTypedDict": ".agent",
    "UnknownAgentTool": ".agent",
    "AgentAliasResponse": ".agentaliasresponse",
    "AgentAliasResponseTypedDict": ".agentaliasresponse",
    "AgentConversation": ".agentconversation",
    "AgentConversationAgentVersion": ".agentconversation",
    "AgentConversationAgentVersionTypedDict": ".agentconversation",
    "AgentConversationTypedDict": ".agentconversation",
    "AgentHandoffDoneEvent": ".agenthandoffdoneevent",
    "AgentHandoffDoneEventTypedDict": ".agenthandoffdoneevent",
    "AgentHandoffEntry": ".agenthandoffentry",
    "AgentHandoffEntryTypedDict": ".agenthandoffentry",
    "AgentHandoffStartedEvent": ".agenthandoffstartedevent",
    "AgentHandoffStartedEventTypedDict": ".agenthandoffstartedevent",
    "AgentsAPIV1AgentsCreateOrUpdateAliasRequest": ".agents_api_v1_agents_create_or_update_aliasop",
    "AgentsAPIV1AgentsCreateOrUpdateAliasRequestTypedDict": ".agents_api_v1_agents_create_or_update_aliasop",
    "AgentsAPIV1AgentsDeleteAliasRequest": ".agents_api_v1_agents_delete_aliasop",
    "AgentsAPIV1AgentsDeleteAliasRequestTypedDict": ".agents_api_v1_agents_delete_aliasop",
    "AgentsAPIV1AgentsDeleteRequest": ".agents_api_v1_agents_deleteop",
    "AgentsAPIV1AgentsDeleteRequestTypedDict": ".agents_api_v1_agents_deleteop",
    "AgentsAPIV1AgentsGetVersionRequest": ".agents_api_v1_agents_get_versionop",
    "AgentsAPIV1AgentsGetVersionRequestTypedDict": ".agents_api_v1_agents_get_versionop",
    "AgentsAPIV1AgentsGetAgentVersion": ".agents_api_v1_agents_getop",
    "AgentsAPIV1AgentsGetAgentVersionTypedDict": ".agents_api_v1_agents_getop",
    "AgentsAPIV1AgentsGetRequest": ".agents_api_v1_agents_getop",
    "AgentsAPIV1AgentsGetRequestTypedDict": ".agents_api_v1_agents_getop",
    "AgentsAPIV1AgentsListVersionAliasesRequest": ".agents_api_v1_agents_list_version_aliasesop",
    "AgentsAPIV1AgentsListVersionAliasesRequestTypedDict": ".agents_api_v1_agents_list_version_aliasesop",
    "AgentsAPIV1AgentsListVersionsRequest": ".agents_api_v1_agents_list_versionsop",
    "AgentsAPIV1AgentsListVersionsRequestTypedDict": ".agents_api_v1_agents_list_versionsop",
    "AgentsAPIV1AgentsListRequest": ".agents_api_v1_agents_listop",
    "AgentsAPIV1AgentsListRequestTypedDict": ".agents_api_v1_agents_listop",
    "AgentsAPIV1AgentsUpdateVersionRequest": ".agents_api_v1_agents_update_versionop",
    "AgentsAPIV1AgentsUpdateVersionRequestTypedDict": ".agents_api_v1_agents_update_versionop",
    "AgentsAPIV1AgentsUpdateRequest": ".agents_api_v1_agents_updateop",
    "AgentsAPIV1AgentsUpdateRequestTypedDict": ".agents_api_v1_agents_updateop",
    "AgentsAPIV1ConversationsAppendStreamRequest": ".agents_api_v1_conversations_append_streamop",
    "AgentsAPIV1ConversationsAppendStreamRequestTypedDict": ".agents_api_v1_conversations_append_streamop",
    "AgentsAPIV1ConversationsAppendRequest": ".agents_api_v1_conversations_appendop",
    "AgentsAPIV1ConversationsAppendRequestTypedDict": ".agents_api_v1_conversations_appendop",
    "AgentsAPIV1ConversationsDeleteRequest": ".agents_api_v1_conversations_deleteop",
    "AgentsAPIV1ConversationsDeleteRequestTypedDict": ".agents_api_v1_conversations_deleteop",
    "AgentsAPIV1ConversationsGetRequest": ".agents_api_v1_conversations_getop",
    "AgentsAPIV1ConversationsGetRequestTypedDict": ".agents_api_v1_conversations_getop",
    "ResponseV1ConversationsGet": ".agents_api_v1_conversations_getop",
    "ResponseV1ConversationsGetTypedDict": ".agents_api_v1_conversations_getop",
    "AgentsAPIV1ConversationsHistoryRequest": ".agents_api_v1_conversations_historyop",
    "AgentsAPIV1ConversationsHistoryRequestTypedDict": ".agents_api_v1_conversations_historyop",
    "AgentsAPIV1ConversationsListRequest": ".agents_api_v1_conversations_listop",
    "AgentsAPIV1ConversationsListRequestTypedDict": ".agents_api_v1_conversations_listop",
    "AgentsAPIV1ConversationsListResponse": ".agents_api_v1_conversations_listop",
    "AgentsAPIV1ConversationsListResponseTypedDict": ".agents_api_v1_conversations_listop",
    "AgentsAPIV1ConversationsMessagesRequest": ".agents_api_v1_conversations_messagesop",
    "AgentsAPIV1ConversationsMessagesRequestTypedDict": ".agents_api_v1_conversations_messagesop",
    "AgentsAPIV1ConversationsRestartStreamRequest": ".agents_api_v1_conversations_restart_streamop",
    "AgentsAPIV1ConversationsRestartStreamRequestTypedDict": ".agents_api_v1_conversations_restart_streamop",
    "AgentsAPIV1ConversationsRestartRequest": ".agents_api_v1_conversations_restartop",
    "AgentsAPIV1ConversationsRestartRequestTypedDict": ".agents_api_v1_conversations_restartop",
    "AgentsCompletionRequest": ".agentscompletionrequest",
    "AgentsCompletionRequestMessage": ".agentscompletionrequest",
    "AgentsCompletionRequestMessageTypedDict": ".agentscompletionrequest",
    "AgentsCompletionRequestStop": ".agentscompletionrequest",
    "AgentsCompletionRequestStopTypedDict": ".agentscompletionrequest",
    "AgentsCompletionRequestToolChoice": ".agentscompletionrequest",
    "AgentsCompletionRequestToolChoiceTypedDict": ".agentscompletionrequest",
    "AgentsCompletionRequestTypedDict": ".agentscompletionrequest",
    "AgentsCompletionStreamRequest": ".agentscompletionstreamrequest",
    "AgentsCompletionStreamRequestMessage": ".agentscompletionstreamrequest",
    "AgentsCompletionStreamRequestMessageTypedDict": ".agentscompletionstreamrequest",
    "AgentsCompletionStreamRequestStop": ".agentscompletionstreamrequest",
    "AgentsCompletionStreamRequestStopTypedDict": ".agentscompletionstreamrequest",
    "AgentsCompletionStreamRequestToolChoice": ".agentscompletionstreamrequest",
    "AgentsCompletionStreamRequestToolChoiceTypedDict": ".agentscompletionstreamrequest",
    "AgentsCompletionStreamRequestTypedDict": ".agentscompletionstreamrequest",
    "APIEndpoint": ".apiendpoint",
    "ArchiveModelResponse": ".archivemodelresponse",
    "ArchiveModelResponseTypedDict": ".archivemodelresponse",
    "AssistantMessage": ".assistantmessage",
    "AssistantMessageContent": ".assistantmessage",
    "AssistantMessageContentTypedDict": ".assistantmessage",
    "AssistantMessageTypedDict": ".assistantmessage",
    "AudioChunk": ".audiochunk",
    "AudioChunkTypedDict": ".audiochunk",
    "AudioEncoding": ".audioencoding",
    "AudioFormat": ".audioformat",
    "AudioFormatTypedDict": ".audioformat",
    "AudioTranscriptionRequest": ".audiotranscriptionrequest",
    "AudioTranscriptionRequestTypedDict": ".audiotranscriptionrequest",
    "AudioTranscriptionRequestStream": ".audiotranscriptionrequeststream",
    "AudioTranscriptionRequestStreamTypedDict": ".audiotranscriptionrequeststream",
    "BaseModelCard": ".basemodelcard",
    "BaseModelCardTypedDict": ".basemodelcard",
    "BatchError": ".batcherror",
    "BatchErrorTypedDict": ".batcherror",
    "BatchJob": ".batchjob",
    "BatchJobTypedDict": ".batchjob",
    "BatchJobStatus": ".batchjobstatus",
    "BatchRequest": ".batchrequest",
    "BatchRequestTypedDict": ".batchrequest",
    "BuiltInConnectors": ".builtinconnectors",
    "ChatClassificationRequest": ".chatclassificationrequest",
    "ChatClassificationRequestTypedDict": ".chatclassificationrequest",
    "ChatCompletionChoice": ".chatcompletionchoice",
    "ChatCompletionChoiceFinishReason": ".chatcompletionchoice",
    "ChatCompletionChoiceTypedDict": ".chatcompletionchoice",
    "ChatCompletionRequest": ".chatcompletionrequest",
    "ChatCompletionRequestMessage": ".chatcompletionrequest",
    "ChatCompletionRequestMessageTypedDict": ".chatcompletionrequest",
    "ChatCompletionRequestStop": ".chatcompletionrequest",
    "ChatCompletionRequestStopTypedDict": ".chatcompletionrequest",
    "ChatCompletionRequestToolChoice": ".chatcompletionrequest",
    "ChatCompletionRequestToolChoiceTypedDict": ".chatcompletionrequest",
    "ChatCompletionRequestTypedDict": ".chatcompletionrequest",
    "ChatCompletionResponse": ".chatcompletionresponse",
    "ChatCompletionResponseTypedDict": ".chatcompletionresponse",
    "ChatCompletionStreamRequest": ".chatcompletionstreamrequest",
    "ChatCompletionStreamRequestMessage": ".chatcompletionstreamrequest",
    "ChatCompletionStreamRequestMessageTypedDict": ".chatcompletionstreamrequest",
    "ChatCompletionStreamRequestStop": ".chatcompletionstreamrequest",
    "ChatCompletionStreamRequestStopTypedDict": ".chatcompletionstreamrequest",
    "ChatCompletionStreamRequestToolChoice": ".chatcompletionstreamrequest",
    "ChatCompletionStreamRequestToolChoiceTypedDict": ".chatcompletionstreamrequest",
    "ChatCompletionStreamRequestTypedDict": ".chatcompletionstreamrequest",
    "ChatModerationRequest": ".chatmoderationrequest",
    "ChatModerationRequestInputs1": ".chatmoderationrequest",
    "ChatModerationRequestInputs1TypedDict": ".chatmoderationrequest",
    "ChatModerationRequestInputs2": ".chatmoderationrequest",
    "ChatModerationRequestInputs2TypedDict": ".chatmoderationrequest",
    "ChatModerationRequestInputs3": ".chatmoderationrequest",
    "ChatModerationRequestInputs3TypedDict": ".chatmoderationrequest",
    "ChatModerationRequestTypedDict": ".chatmoderationrequest",
    "Checkpoint": ".checkpoint",
    "CheckpointTypedDict": ".checkpoint",
    "ClassificationRequest": ".classificationrequest",
    "ClassificationRequestInputs": ".classificationrequest",
    "ClassificationRequestInputsTypedDict": ".classificationrequest",
    "ClassificationRequestTypedDict": ".classificationrequest",
    "ClassificationResponse": ".classificationresponse",
    "ClassificationResponseTypedDict": ".classificationresponse",
    "ClassificationTargetResult": ".classificationtargetresult",
    "ClassificationTargetResultTypedDict": ".classificationtargetresult",
    "ClassifierFineTunedModel": ".classifierfinetunedmodel",
    "ClassifierFineTunedModelTypedDict": ".classifierfinetunedmodel",
    "ClassifierFineTuningJob": ".classifierfinetuningjob",
    "ClassifierFineTuningJobIntegration": ".classifierfinetuningjob",
    "ClassifierFineTuningJobIntegrationTypedDict": ".classifierfinetuningjob",
    "ClassifierFineTuningJobStatus": ".classifierfinetuningjob",
    "ClassifierFineTuningJobTypedDict": ".classifierfinetuningjob",
    "UnknownClassifierFineTuningJobIntegration": ".classifierfinetuningjob",
    "ClassifierFineTuningJobDetails": ".classifierfinetuningjobdetails",
    "ClassifierFineTuningJobDetailsIntegration": ".classifierfinetuningjobdetails",
    "ClassifierFineTuningJobDetailsIntegrationTypedDict": ".classifierfinetuningjobdetails",
    "ClassifierFineTuningJobDetailsStatus": ".classifierfinetuningjobdetails",
    "ClassifierFineTuningJobDetailsTypedDict": ".classifierfinetuningjobdetails",
    "UnknownClassifierFineTuningJobDetailsIntegration": ".classifierfinetuningjobdetails",
    "ClassifierTarget": ".classifiertarget",
    "ClassifierTargetTypedDict": ".classifiertarget",
    "ClassifierTargetResult": ".classifiertargetresult",
    "ClassifierTargetResultTypedDict": ".classifiertargetresult",
    "ClassifierTrainingParameters": ".classifiertrainingparameters",
    "ClassifierTrainingParametersTypedDict": ".classifiertrainingparameters",
    "CodeInterpreterTool": ".codeinterpretertool",
    "CodeInterpreterToolTypedDict": ".codeinterpretertool",
    "CompletionArgs": ".completionargs",
    "CompletionArgsTypedDict": ".completionargs",
    "CompletionArgsStop": ".completionargsstop",
    "CompletionArgsStopTypedDict": ".completionargsstop",
    "CompletionChunk": ".completionchunk",
    "CompletionChunkTypedDict": ".completionchunk",
    "CompletionEvent": ".completionevent",
    "CompletionEventTypedDict": ".completionevent",
    "CompletionFineTunedModel": ".completionfinetunedmodel",
    "CompletionFineTunedModelTypedDict": ".completionfinetunedmodel",
    "CompletionFineTuningJob": ".completionfinetuningjob",
    "CompletionFineTuningJobIntegration": ".completionfinetuningjob",
    "CompletionFineTuningJobIntegrationTypedDict": ".completionfinetuningjob",
    "CompletionFineTuningJobRepository": ".completionfinetuningjob",
    "CompletionFineTuningJobRepositoryTypedDict": ".completionfinetuningjob",
    "CompletionFineTuningJobStatus": ".completionfinetuningjob",
    "CompletionFineTuningJobTypedDict": ".completionfinetuningjob",
    "UnknownCompletionFineTuningJobIntegration": ".completionfinetuningjob",
    "UnknownCompletionFineTuningJobRepository": ".completionfinetuningjob",
    "CompletionFineTuningJobDetails": ".completionfinetuningjobdetails",
    "CompletionFineTuningJobDetailsIntegration": ".completionfinetuningjobdetails",
    "CompletionFineTuningJobDetailsIntegrationTypedDict": ".completionfinetuningjobdetails",
    "CompletionFineTuningJobDetailsRepository": ".completionfinetuningjobdetails",
    "CompletionFineTuningJobDetailsRepositoryTypedDict": ".completionfinetuningjobdetails",
    "CompletionFineTuningJobDetailsStatus": ".completionfinetuningjobdetails",
    "CompletionFineTuningJobDetailsTypedDict": ".completionfinetuningjobdetails",
    "UnknownCompletionFineTuningJobDetailsIntegration": ".completionfinetuningjobdetails",
    "UnknownCompletionFineTuningJobDetailsRepository": ".completionfinetuningjobdetails",
    "CompletionResponseStreamChoice": ".completionresponsestreamchoice",
    "CompletionResponseStreamChoiceFinishReason": ".completionresponsestreamchoice",
    "CompletionResponseStreamChoiceTypedDict": ".completionresponsestreamchoice",
    "CompletionTrainingParameters": ".completiontrainingparameters",
    "CompletionTrainingParametersTypedDict": ".completiontrainingparameters",
    "ContentChunk": ".contentchunk",
    "ContentChunkTypedDict": ".contentchunk",
    "UnknownContentChunk": ".contentchunk",
    "ConversationAppendRequest": ".conversationappendrequest",
    "ConversationAppendRequestHandoffExecution": ".conversationappendrequest",
    "ConversationAppendRequestTypedDict": ".conversationappendrequest",
    "ConversationAppendStreamRequest": ".conversationappendstreamrequest",
    "ConversationAppendStreamRequestHandoffExecution": ".conversationappendstreamrequest",
    "ConversationAppendStreamRequestTypedDict": ".conversationappendstreamrequest",
    "ConversationEvents": ".conversationevents",
    "ConversationEventsData": ".conversationevents",
    "ConversationEventsDataTypedDict": ".conversationevents",
    "ConversationEventsTypedDict": ".conversationevents",
    "UnknownConversationEventsData": ".conversationevents",
    "ConversationHistory": ".conversationhistory",
    "ConversationHistoryTypedDict": ".conversationhistory",
    "Entry": ".conversationhistory",
    "EntryTypedDict": ".conversationhistory",
    "ConversationInputs": ".conversationinputs",
    "ConversationInputsTypedDict": ".conversationinputs",
    "ConversationMessages": ".conversationmessages",
    "ConversationMessagesTypedDict": ".conversationmessages",
    "ConversationRequest": ".conversationrequest",
    "ConversationRequestAgentVersion": ".conversationrequest",
    "ConversationRequestAgentVersionTypedDict": ".conversationrequest",
    "ConversationRequestHandoffExecution": ".conversationrequest",
    "ConversationRequestTool": ".conversationrequest",
    "ConversationRequestToolTypedDict": ".conversationrequest",
    "ConversationRequestTypedDict": ".conversationrequest",
    "ConversationResponse": ".conversationresponse",
    "ConversationResponseTypedDict": ".conversationresponse",
    "Output": ".conversationresponse",
    "OutputTypedDict": ".conversationresponse",
    "ConversationRestartRequest": ".conversationrestartrequest",
    "ConversationRestartRequestAgentVersion": ".conversationrestartrequest",
    "ConversationRestartRequestAgentVersionTypedDict": ".conversationrestartrequest",
    "ConversationRestartRequestHandoffExecution": ".conversationrestartrequest",
    "ConversationRestartRequestTypedDict": ".conversationrestartrequest",
    "ConversationRestartStreamRequest": ".conversationrestartstreamrequest",
    "ConversationRestartStreamRequestAgentVersion": ".conversationrestartstreamrequest",
    "ConversationRestartStreamRequestAgentVersionTypedDict": ".conversationrestartstreamrequest",
    "ConversationRestartStreamRequestHandoffExecution": ".conversationrestartstreamrequest",
    "ConversationRestartStreamRequestTypedDict": ".conversationrestartstreamrequest",
    "ConversationStreamRequest": ".conversationstreamrequest",
    "ConversationStreamRequestAgentVersion": ".conversationstreamrequest",
    "ConversationStreamRequestAgentVersionTypedDict": ".conversationstreamrequest",
    "ConversationStreamRequestHandoffExecution": ".conversationstreamrequest",
    "ConversationStreamRequestTool": ".conversationstreamrequest",
    "ConversationStreamRequestToolTypedDict": ".conversationstreamrequest",
    "ConversationStreamRequestTypedDict": ".conversationstreamrequest",
    "ConversationThinkChunk": ".conversationthinkchunk",
    "ConversationThinkChunkThinking": ".conversationthinkchunk",
    "ConversationThinkChunkThinkingTypedDict": ".conversationthinkchunk",
    "ConversationThinkChunkTypedDict": ".conversationthinkchunk",
    "ConversationUsageInfo": ".conversationusageinfo",
    "ConversationUsageInfoTypedDict": ".conversationusageinfo",
    "CreateAgentRequest": ".createagentrequest",
    "CreateAgentRequestTool": ".createagentrequest",
    "CreateAgentRequestToolTypedDict": ".createagentrequest",
    "CreateAgentRequestTypedDict": ".createagentrequest",
    "CreateBatchJobRequest": ".createbatchjobrequest",
    "CreateBatchJobRequestTypedDict": ".createbatchjobrequest",
    "CreateFileResponse": ".createfileresponse",
    "CreateFileResponseTypedDict": ".createfileresponse",
    "CreateFineTuningJobRequest": ".createfinetuningjobrequest",
    "CreateFineTuningJobRequestIntegration": ".createfinetuningjobrequest",
    "CreateFineTuningJobRequestIntegrationTypedDict": ".createfinetuningjobrequest",
    "CreateFineTuningJobRequestRepository": ".createfinetuningjobrequest",
    "CreateFineTuningJobRequestRepositoryTypedDict": ".createfinetuningjobrequest",
    "CreateFineTuningJobRequestTypedDict": ".createfinetuningjobrequest",
    "Hyperparameters": ".createfinetuningjobrequest",
    "HyperparametersTypedDict": ".createfinetuningjobrequest",
    "CreateLibraryRequest": ".createlibraryrequest",
    "CreateLibraryRequestTypedDict": ".createlibraryrequest",
    "DeleteModelV1ModelsModelIDDeleteRequest": ".delete_model_v1_models_model_id_deleteop",
    "DeleteModelV1ModelsModelIDDeleteRequestTypedDict": ".delete_model_v1_models_model_id_deleteop",
    "DeleteFileResponse": ".deletefileresponse",
    "DeleteFileResponseTypedDict": ".deletefileresponse",
    "DeleteModelOut": ".deletemodelout",
    "DeleteModelOutTypedDict": ".deletemodelout",
    "DeltaMessage": ".deltamessage",
    "DeltaMessageContent": ".deltamessage",
    "DeltaMessageContentTypedDict": ".deltamessage",
    "DeltaMessageTypedDict": ".deltamessage",
    "Document": ".document",
    "DocumentTypedDict": ".document",
    "DocumentLibraryTool": ".documentlibrarytool",
    "DocumentLibraryToolTypedDict": ".documentlibrarytool",
    "DocumentTextContent": ".documenttextcontent",
    "DocumentTextContentTypedDict": ".documenttextcontent",
    "DocumentURLChunk": ".documenturlchunk",
    "DocumentURLChunkTypedDict": ".documenturlchunk",
    "EmbeddingDtype": ".embeddingdtype",
    "EmbeddingRequest": ".embeddingrequest",
    "EmbeddingRequestInputs": ".embeddingrequest",
    "EmbeddingRequestInputsTypedDict": ".embeddingrequest",
    "EmbeddingRequestTypedDict": ".embeddingrequest",
    "EmbeddingResponse": ".embeddingresponse",
    "EmbeddingResponseTypedDict": ".embeddingresponse",
    "EmbeddingResponseData": ".embeddingresponsedata",
    "EmbeddingResponseDataTypedDict": ".embeddingresponsedata",
    "EncodingFormat": ".encodingformat",
    "EntityType": ".entitytype",
    "Event": ".event",
    "EventTypedDict": ".event",
    "File": ".file",
    "FileTypedDict": ".file",
    "FileChunk": ".filechunk",
    "FileChunkTypedDict": ".filechunk",
    "FilePurpose": ".filepurpose",
    "FilesAPIRoutesDeleteFileRequest": ".files_api_routes_delete_fileop",
    "FilesAPIRoutesDeleteFileRequestTypedDict": ".files_api_routes_delete_fileop",
    "FilesAPIRoutesDownloadFileRequest": ".files_api_routes_download_fileop",
    "FilesAPIRoutesDownloadFileRequestTypedDict": ".files_api_routes_download_fileop",
    "FilesAPIRoutesGetSignedURLRequest": ".files_api_routes_get_signed_urlop",
    "FilesAPIRoutesGetSignedURLRequestTypedDict": ".files_api_routes_get_signed_urlop",
    "FilesAPIRoutesListFilesRequest": ".files_api_routes_list_filesop",
    "FilesAPIRoutesListFilesRequestTypedDict": ".files_api_routes_list_filesop",
    "FilesAPIRoutesRetrieveFileRequest": ".files_api_routes_retrieve_fileop",
    "FilesAPIRoutesRetrieveFileRequestTypedDict": ".files_api_routes_retrieve_fileop",
    "MultiPartBodyParams": ".files_api_routes_upload_fileop",
    "MultiPartBodyParamsTypedDict": ".files_api_routes_upload_fileop",
    "FileSchema": ".fileschema",
    "FileSchemaTypedDict": ".fileschema",
    "FIMCompletionRequest": ".fimcompletionrequest",
    "FIMCompletionRequestStop": ".fimcompletionrequest",
    "FIMCompletionRequestStopTypedDict": ".fimcompletionrequest",
    "FIMCompletionRequestTypedDict": ".fimcompletionrequest",
    "FIMCompletionResponse": ".fimcompletionresponse",
    "FIMCompletionResponseTypedDict": ".fimcompletionresponse",
    "FIMCompletionStreamRequest": ".fimcompletionstreamrequest",
    "FIMCompletionStreamRequestStop": ".fimcompletionstreamrequest",
    "FIMCompletionStreamRequestStopTypedDict": ".fimcompletionstreamrequest",
    "FIMCompletionStreamRequestTypedDict": ".fimcompletionstreamrequest",
    "FineTuneableModelType": ".finetuneablemodeltype",
    "FineTunedModelCapabilities": ".finetunedmodelcapabilities",
    "FineTunedModelCapabilitiesTypedDict": ".finetunedmodelcapabilities",
    "FTClassifierLossFunction": ".ftclassifierlossfunction",
    "FTModelCard": ".ftmodelcard",
    "FTModelCardTypedDict": ".ftmodelcard",
    "Function": ".function",
    "FunctionTypedDict": ".function",
    "Arguments": ".functioncall",
    "ArgumentsTypedDict": ".functioncall",
    "FunctionCall": ".functioncall",
    "FunctionCallTypedDict": ".functioncall",
    "FunctionCallEntry": ".functioncallentry",
    "FunctionCallEntryConfirmationStatus": ".functioncallentry",
    "FunctionCallEntryTypedDict": ".functioncallentry",
    "FunctionCallEntryArguments": ".functioncallentryarguments",
    "FunctionCallEntryArgumentsTypedDict": ".functioncallentryarguments",
    "FunctionCallEvent": ".functioncallevent",
    "FunctionCallEventConfirmationStatus": ".functioncallevent",
    "FunctionCallEventTypedDict": ".functioncallevent",
    "FunctionName": ".functionname",
    "FunctionNameTypedDict": ".functionname",
    "FunctionResultEntry": ".functionresultentry",
    "FunctionResultEntryTypedDict": ".functionresultentry",
    "FunctionTool": ".functiontool",
    "FunctionToolTypedDict": ".functiontool",
    "GetFileResponse": ".getfileresponse",
    "GetFileResponseTypedDict": ".getfileresponse",
    "GetSignedURLResponse": ".getsignedurlresponse",
    "GetSignedURLResponseTypedDict": ".getsignedurlresponse",
    "GithubRepository": ".githubrepository",
    "GithubRepositoryTypedDict": ".githubrepository",
    "GithubRepositoryIn": ".githubrepositoryin",
    "GithubRepositoryInTypedDict": ".githubrepositoryin",
    "ImageDetail": ".imagedetail",
    "ImageGenerationTool": ".imagegenerationtool",
    "ImageGenerationToolTypedDict": ".imagegenerationtool",
    "ImageURL": ".imageurl",
    "ImageURLTypedDict": ".imageurl",
    "ImageURLChunk": ".imageurlchunk",
    "ImageURLChunkTypedDict": ".imageurlchunk",
    "ImageURLUnion": ".imageurlchunk",
    "ImageURLUnionTypedDict": ".imageurlchunk",
    "InputEntries": ".inputentries",
    "InputEntriesTypedDict": ".inputentries",
    "Inputs": ".inputs",
    "InputsTypedDict": ".inputs",
    "InstructRequest": ".instructrequest",
    "InstructRequestMessage": ".instructrequest",
    "InstructRequestMessageTypedDict": ".instructrequest",
    "InstructRequestTypedDict": ".instructrequest",
    "JobMetadata": ".jobmetadata",
    "JobMetadataTypedDict": ".jobmetadata",
    "JobsAPIRoutesBatchCancelBatchJobRequest": ".jobs_api_routes_batch_cancel_batch_jobop",
    "JobsAPIRoutesBatchCancelBatchJobRequestTypedDict": ".jobs_api_routes_batch_cancel_batch_jobop",
    "JobsAPIRoutesBatchGetBatchJobRequest": ".jobs_api_routes_batch_get_batch_jobop",
    "JobsAPIRoutesBatchGetBatchJobRequestTypedDict": ".jobs_api_routes_batch_get_batch_jobop",
    "JobsAPIRoutesBatchGetBatchJobsRequest": ".jobs_api_routes_batch_get_batch_jobsop",
    "JobsAPIRoutesBatchGetBatchJobsRequestTypedDict": ".jobs_api_routes_batch_get_batch_jobsop",
    "OrderBy": ".jobs_api_routes_batch_get_batch_jobsop",
    "JobsAPIRoutesFineTuningArchiveFineTunedModelRequest": ".jobs_api_routes_fine_tuning_archive_fine_tuned_modelop",
    "JobsAPIRoutesFineTuningArchiveFineTunedModelRequestTypedDict": ".jobs_api_routes_fine_tuning_archive_fine_tuned_modelop",
    "JobsAPIRoutesFineTuningCancelFineTuningJobRequest": ".jobs_api_routes_fine_tuning_cancel_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningCancelFineTuningJobRequestTypedDict": ".jobs_api_routes_fine_tuning_cancel_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningCancelFineTuningJobResponse": ".jobs_api_routes_fine_tuning_cancel_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningCancelFineTuningJobResponseTypedDict": ".jobs_api_routes_fine_tuning_cancel_fine_tuning_jobop",
    "UnknownJobsAPIRoutesFineTuningCancelFineTuningJobResponse": ".jobs_api_routes_fine_tuning_cancel_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningCreateFineTuningJobResponse": ".jobs_api_routes_fine_tuning_create_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningCreateFineTuningJobResponseTypedDict": ".jobs_api_routes_fine_tuning_create_fine_tuning_jobop",
    "Response": ".jobs_api_routes_fine_tuning_create_fine_tuning_jobop",
    "ResponseTypedDict": ".jobs_api_routes_fine_tuning_create_fine_tuning_jobop",
    "UnknownResponse": ".jobs_api_routes_fine_tuning_create_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningGetFineTuningJobRequest": ".jobs_api_routes_fine_tuning_get_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningGetFineTuningJobRequestTypedDict": ".jobs_api_routes_fine_tuning_get_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningGetFineTuningJobResponse": ".jobs_api_routes_fine_tuning_get_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningGetFineTuningJobResponseTypedDict": ".jobs_api_routes_fine_tuning_get_fine_tuning_jobop",
    "UnknownJobsAPIRoutesFineTuningGetFineTuningJobResponse": ".jobs_api_routes_fine_tuning_get_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningGetFineTuningJobsRequest": ".jobs_api_routes_fine_tuning_get_fine_tuning_jobsop",
    "JobsAPIRoutesFineTuningGetFineTuningJobsRequestTypedDict": ".jobs_api_routes_fine_tuning_get_fine_tuning_jobsop",
    "JobsAPIRoutesFineTuningGetFineTuningJobsStatus": ".jobs_api_routes_fine_tuning_get_fine_tuning_jobsop",
    "JobsAPIRoutesFineTuningStartFineTuningJobRequest": ".jobs_api_routes_fine_tuning_start_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningStartFineTuningJobRequestTypedDict": ".jobs_api_routes_fine_tuning_start_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningStartFineTuningJobResponse": ".jobs_api_routes_fine_tuning_start_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningStartFineTuningJobResponseTypedDict": ".jobs_api_routes_fine_tuning_start_fine_tuning_jobop",
    "UnknownJobsAPIRoutesFineTuningStartFineTuningJobResponse": ".jobs_api_routes_fine_tuning_start_fine_tuning_jobop",
    "JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequest": ".jobs_api_routes_fine_tuning_unarchive_fine_tuned_modelop",
    "JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequestTypedDict": ".jobs_api_routes_fine_tuning_unarchive_fine_tuned_modelop",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelRequest": ".jobs_api_routes_fine_tuning_update_fine_tuned_modelop",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelRequestTypedDict": ".jobs_api_routes_fine_tuning_update_fine_tuned_modelop",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelResponse": ".jobs_api_routes_fine_tuning_update_fine_tuned_modelop",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelResponseTypedDict": ".jobs_api_routes_fine_tuning_update_fine_tuned_modelop",
    "UnknownJobsAPIRoutesFineTuningUpdateFineTunedModelResponse": ".jobs_api_routes_fine_tuning_update_fine_tuned_modelop",
    "JSONSchema": ".jsonschema",
    "JSONSchemaTypedDict": ".jsonschema",
    "LegacyJobMetadata": ".legacyjobmetadata",
    "LegacyJobMetadataTypedDict": ".legacyjobmetadata",
    "LibrariesDeleteV1Request": ".libraries_delete_v1op",
    "LibrariesDeleteV1RequestTypedDict": ".libraries_delete_v1op",
    "LibrariesDocumentsDeleteV1Request": ".libraries_documents_delete_v1op",
    "LibrariesDocumentsDeleteV1RequestTypedDict": ".libraries_documents_delete_v1op",
    "LibrariesDocumentsGetExtractedTextSignedURLV1Request": ".libraries_documents_get_extracted_text_signed_url_v1op",
    "LibrariesDocumentsGetExtractedTextSignedURLV1RequestTypedDict": ".libraries_documents_get_extracted_text_signed_url_v1op",
    "LibrariesDocumentsGetSignedURLV1Request": ".libraries_documents_get_signed_url_v1op",
    "LibrariesDocumentsGetSignedURLV1RequestTypedDict": ".libraries_documents_get_signed_url_v1op",
    "LibrariesDocumentsGetStatusV1Request": ".libraries_documents_get_status_v1op",
    "LibrariesDocumentsGetStatusV1RequestTypedDict": ".libraries_documents_get_status_v1op",
    "LibrariesDocumentsGetTextContentV1Request": ".libraries_documents_get_text_content_v1op",
    "LibrariesDocumentsGetTextContentV1RequestTypedDict": ".libraries_documents_get_text_content_v1op",
    "LibrariesDocumentsGetV1Request": ".libraries_documents_get_v1op",
    "LibrariesDocumentsGetV1RequestTypedDict": ".libraries_documents_get_v1op",
    "LibrariesDocumentsListV1Request": ".libraries_documents_list_v1op",
    "LibrariesDocumentsListV1RequestTypedDict": ".libraries_documents_list_v1op",
    "LibrariesDocumentsReprocessV1Request": ".libraries_documents_reprocess_v1op",
    "LibrariesDocumentsReprocessV1RequestTypedDict": ".libraries_documents_reprocess_v1op",
    "LibrariesDocumentsUpdateV1Request": ".libraries_documents_update_v1op",
    "LibrariesDocumentsUpdateV1RequestTypedDict": ".libraries_documents_update_v1op",
    "DocumentUpload": ".libraries_documents_upload_v1op",
    "DocumentUploadTypedDict": ".libraries_documents_upload_v1op",
    "LibrariesDocumentsUploadV1Request": ".libraries_documents_upload_v1op",
    "LibrariesDocumentsUploadV1RequestTypedDict": ".libraries_documents_upload_v1op",
    "LibrariesGetV1Request": ".libraries_get_v1op",
    "LibrariesGetV1RequestTypedDict": ".libraries_get_v1op",
    "LibrariesShareCreateV1Request": ".libraries_share_create_v1op",
    "LibrariesShareCreateV1RequestTypedDict": ".libraries_share_create_v1op",
    "LibrariesShareDeleteV1Request": ".libraries_share_delete_v1op",
    "LibrariesShareDeleteV1RequestTypedDict": ".libraries_share_delete_v1op",
    "LibrariesShareListV1Request": ".libraries_share_list_v1op",
    "LibrariesShareListV1RequestTypedDict": ".libraries_share_list_v1op",
    "LibrariesUpdateV1Request": ".libraries_update_v1op",
    "LibrariesUpdateV1RequestTypedDict": ".libraries_update_v1op",
    "Library": ".library",
    "LibraryTypedDict": ".library",
    "ListBatchJobsResponse": ".listbatchjobsresponse",
    "ListBatchJobsResponseTypedDict": ".listbatchjobsresponse",
    "ListDocumentsResponse": ".listdocumentsresponse",
    "ListDocumentsResponseTypedDict": ".listdocumentsresponse",
    "ListFilesResponse": ".listfilesresponse",
    "ListFilesResponseTypedDict": ".listfilesresponse",
    "ListFineTuningJobsResponse": ".listfinetuningjobsresponse",
    "ListFineTuningJobsResponseData": ".listfinetuningjobsresponse",
    "ListFineTuningJobsResponseDataTypedDict": ".listfinetuningjobsresponse",
    "ListFineTuningJobsResponseTypedDict": ".listfinetuningjobsresponse",
    "UnknownListFineTuningJobsResponseData": ".listfinetuningjobsresponse",
    "ListLibrariesResponse": ".listlibrariesresponse",
    "ListLibrariesResponseTypedDict": ".listlibrariesresponse",
    "ListSharingOut": ".listsharingout",
    "ListSharingOutTypedDict": ".listsharingout",
    "MessageEntries": ".messageentries",
    "MessageEntriesTypedDict": ".messageentries",
    "MessageInputContentChunks": ".messageinputcontentchunks",
    "MessageInputContentChunksTypedDict": ".messageinputcontentchunks",
    "MessageInputEntry": ".messageinputentry",
    "MessageInputEntryContent": ".messageinputentry",
    "MessageInputEntryContentTypedDict": ".messageinputentry",
    "MessageInputEntryTypedDict": ".messageinputentry",
    "Role": ".messageinputentry",
    "MessageOutputContentChunks": ".messageoutputcontentchunks",
    "MessageOutputContentChunksTypedDict": ".messageoutputcontentchunks",
    "MessageOutputEntry": ".messageoutputentry",
    "MessageOutputEntryContent": ".messageoutputentry",
    "MessageOutputEntryContentTypedDict": ".messageoutputentry",
    "MessageOutputEntryTypedDict": ".messageoutputentry",
    "MessageOutputEvent": ".messageoutputevent",
    "MessageOutputEventContent": ".messageoutputevent",
    "MessageOutputEventContentTypedDict": ".messageoutputevent",
    "MessageOutputEventTypedDict": ".messageoutputevent",
    "Metric": ".metric",
    "MetricTypedDict": ".metric",
    "MistralPromptMode": ".mistralpromptmode",
    "ModelCapabilities": ".modelcapabilities",
    "ModelCapabilitiesTypedDict": ".modelcapabilities",
    "ModelConversation": ".modelconversation",
    "ModelConversationTool": ".modelconversation",
    "ModelConversationToolTypedDict": ".modelconversation",
    "ModelConversationTypedDict": ".modelconversation",
    "UnknownModelConversationTool": ".modelconversation",
    "ModelList": ".modellist",
    "ModelListData": ".modellist",
    "ModelListDataTypedDict": ".modellist",
    "ModelListTypedDict": ".modellist",
    "UnknownModelListData": ".modellist",
    "ModerationObject": ".moderationobject",
    "ModerationObjectTypedDict": ".moderationobject",
    "ModerationResponse": ".moderationresponse",
    "ModerationResponseTypedDict": ".moderationresponse",
    "OCRImageObject": ".ocrimageobject",
    "OCRImageObjectTypedDict": ".ocrimageobject",
    "OCRPageDimensions": ".ocrpagedimensions",
    "OCRPageDimensionsTypedDict": ".ocrpagedimensions",
    "OCRPageObject": ".ocrpageobject",
    "OCRPageObjectTypedDict": ".ocrpageobject",
    "DocumentUnion": ".ocrrequest",
    "DocumentUnionTypedDict": ".ocrrequest",
    "OCRRequest": ".ocrrequest",
    "OCRRequestTypedDict": ".ocrrequest",
    "TableFormat": ".ocrrequest",
    "OCRResponse": ".ocrresponse",
    "OCRResponseTypedDict": ".ocrresponse",
    "Format": ".ocrtableobject",
    "OCRTableObject": ".ocrtableobject",
    "OCRTableObjectTypedDict": ".ocrtableobject",
    "OCRUsageInfo": ".ocrusageinfo",
    "OCRUsageInfoTypedDict": ".ocrusageinfo",
    "OutputContentChunks": ".outputcontentchunks",
    "OutputContentChunksTypedDict": ".outputcontentchunks",
    "PaginationInfo": ".paginationinfo",
    "PaginationInfoTypedDict": ".paginationinfo",
    "Prediction": ".prediction",
    "PredictionTypedDict": ".prediction",
    "ProcessingStatusOut": ".processingstatusout",
    "ProcessingStatusOutTypedDict": ".processingstatusout",
    "RealtimeTranscriptionError": ".realtimetranscriptionerror",
    "RealtimeTranscriptionErrorTypedDict": ".realtimetranscriptionerror",
    "RealtimeTranscriptionErrorDetail": ".realtimetranscriptionerrordetail",
    "RealtimeTranscriptionErrorDetailMessage": ".realtimetranscriptionerrordetail",
    "RealtimeTranscriptionErrorDetailMessageTypedDict": ".realtimetranscriptionerrordetail",
    "RealtimeTranscriptionErrorDetailTypedDict": ".realtimetranscriptionerrordetail",
    "RealtimeTranscriptionInputAudioAppend": ".realtimetranscriptioninputaudioappend",
    "RealtimeTranscriptionInputAudioAppendTypedDict": ".realtimetranscriptioninputaudioappend",
    "RealtimeTranscriptionInputAudioEnd": ".realtimetranscriptioninputaudioend",
    "RealtimeTranscriptionInputAudioEndTypedDict": ".realtimetranscriptioninputaudioend",
    "RealtimeTranscriptionInputAudioFlush": ".realtimetranscriptioninputaudioflush",
    "RealtimeTranscriptionInputAudioFlushTypedDict": ".realtimetranscriptioninputaudioflush",
    "RealtimeTranscriptionSession": ".realtimetranscriptionsession",
    "RealtimeTranscriptionSessionTypedDict": ".realtimetranscriptionsession",
    "RealtimeTranscriptionSessionCreated": ".realtimetranscriptionsessioncreated",
    "RealtimeTranscriptionSessionCreatedTypedDict": ".realtimetranscriptionsessioncreated",
    "RealtimeTranscriptionSessionUpdated": ".realtimetranscriptionsessionupdated",
    "RealtimeTranscriptionSessionUpdatedTypedDict": ".realtimetranscriptionsessionupdated",
    "RealtimeTranscriptionSessionUpdateMessage": ".realtimetranscriptionsessionupdatemessage",
    "RealtimeTranscriptionSessionUpdateMessageTypedDict": ".realtimetranscriptionsessionupdatemessage",
    "RealtimeTranscriptionSessionUpdatePayload": ".realtimetranscriptionsessionupdatepayload",
    "RealtimeTranscriptionSessionUpdatePayloadTypedDict": ".realtimetranscriptionsessionupdatepayload",
    "ReferenceChunk": ".referencechunk",
    "ReferenceChunkTypedDict": ".referencechunk",
    "RequestSource": ".requestsource",
    "ResponseDoneEvent": ".responsedoneevent",
    "ResponseDoneEventTypedDict": ".responsedoneevent",
    "ResponseErrorEvent": ".responseerrorevent",
    "ResponseErrorEventTypedDict": ".responseerrorevent",
    "ResponseFormat": ".responseformat",
    "ResponseFormatTypedDict": ".responseformat",
    "ResponseFormats": ".responseformats",
    "ResponseStartedEvent": ".responsestartedevent",
    "ResponseStartedEventTypedDict": ".responsestartedevent",
    "ResponseRetrieveModelV1ModelsModelIDGet": ".retrieve_model_v1_models_model_id_getop",
    "ResponseRetrieveModelV1ModelsModelIDGetTypedDict": ".retrieve_model_v1_models_model_id_getop",
    "RetrieveModelV1ModelsModelIDGetRequest": ".retrieve_model_v1_models_model_id_getop",
    "RetrieveModelV1ModelsModelIDGetRequestTypedDict": ".retrieve_model_v1_models_model_id_getop",
    "UnknownResponseRetrieveModelV1ModelsModelIDGet": ".retrieve_model_v1_models_model_id_getop",
    "SampleType": ".sampletype",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "ShareEnum": ".shareenum",
    "SharingDelete": ".sharingdelete",
    "SharingDeleteTypedDict": ".sharingdelete",
    "SharingIn": ".sharingin",
    "SharingInTypedDict": ".sharingin",
    "SharingOut": ".sharingout",
    "SharingOutTypedDict": ".sharingout",
    "Source": ".source",
    "SSETypes": ".ssetypes",
    "SystemMessage": ".systemmessage",
    "SystemMessageContent": ".systemmessage",
    "SystemMessageContentTypedDict": ".systemmessage",
    "SystemMessageTypedDict": ".systemmessage",
    "SystemMessageContentChunks": ".systemmessagecontentchunks",
    "SystemMessageContentChunksTypedDict": ".systemmessagecontentchunks",
    "TextChunk": ".textchunk",
    "TextChunkTypedDict": ".textchunk",
    "ThinkChunk": ".thinkchunk",
    "ThinkChunkThinking": ".thinkchunk",
    "ThinkChunkThinkingTypedDict": ".thinkchunk",
    "ThinkChunkTypedDict": ".thinkchunk",
    "TimestampGranularity": ".timestampgranularity",
    "Tool": ".tool",
    "ToolTypedDict": ".tool",
    "ToolCall": ".toolcall",
    "ToolCallTypedDict": ".toolcall",
    "Confirmation": ".toolcallconfirmation",
    "ToolCallConfirmation": ".toolcallconfirmation",
    "ToolCallConfirmationTypedDict": ".toolcallconfirmation",
    "ToolChoice": ".toolchoice",
    "ToolChoiceTypedDict": ".toolchoice",
    "ToolChoiceEnum": ".toolchoiceenum",
    "ToolConfiguration": ".toolconfiguration",
    "ToolConfigurationTypedDict": ".toolconfiguration",
    "ToolExecutionDeltaEvent": ".toolexecutiondeltaevent",
    "ToolExecutionDeltaEventName": ".toolexecutiondeltaevent",
    "ToolExecutionDeltaEventNameTypedDict": ".toolexecutiondeltaevent",
    "ToolExecutionDeltaEventTypedDict": ".toolexecutiondeltaevent",
    "ToolExecutionDoneEvent": ".toolexecutiondoneevent",
    "ToolExecutionDoneEventName": ".toolexecutiondoneevent",
    "ToolExecutionDoneEventNameTypedDict": ".toolexecutiondoneevent",
    "ToolExecutionDoneEventTypedDict": ".toolexecutiondoneevent",
    "ToolExecutionEntry": ".toolexecutionentry",
    "ToolExecutionEntryName": ".toolexecutionentry",
    "ToolExecutionEntryNameTypedDict": ".toolexecutionentry",
    "ToolExecutionEntryTypedDict": ".toolexecutionentry",
    "ToolExecutionStartedEvent": ".toolexecutionstartedevent",
    "ToolExecutionStartedEventName": ".toolexecutionstartedevent",
    "ToolExecutionStartedEventNameTypedDict": ".toolexecutionstartedevent",
    "ToolExecutionStartedEventTypedDict": ".toolexecutionstartedevent",
    "ToolFileChunk": ".toolfilechunk",
    "ToolFileChunkTool": ".toolfilechunk",
    "ToolFileChunkToolTypedDict": ".toolfilechunk",
    "ToolFileChunkTypedDict": ".toolfilechunk",
    "ToolMessage": ".toolmessage",
    "ToolMessageContent": ".toolmessage",
    "ToolMessageContentTypedDict": ".toolmessage",
    "ToolMessageTypedDict": ".toolmessage",
    "ToolReferenceChunk": ".toolreferencechunk",
    "ToolReferenceChunkTool": ".toolreferencechunk",
    "ToolReferenceChunkToolTypedDict": ".toolreferencechunk",
    "ToolReferenceChunkTypedDict": ".toolreferencechunk",
    "ToolTypes": ".tooltypes",
    "TrainingFile": ".trainingfile",
    "TrainingFileTypedDict": ".trainingfile",
    "TranscriptionResponse": ".transcriptionresponse",
    "TranscriptionResponseTypedDict": ".transcriptionresponse",
    "TranscriptionSegmentChunk": ".transcriptionsegmentchunk",
    "TranscriptionSegmentChunkTypedDict": ".transcriptionsegmentchunk",
    "TranscriptionStreamDone": ".transcriptionstreamdone",
    "TranscriptionStreamDoneTypedDict": ".transcriptionstreamdone",
    "TranscriptionStreamEvents": ".transcriptionstreamevents",
    "TranscriptionStreamEventsData": ".transcriptionstreamevents",
    "TranscriptionStreamEventsDataTypedDict": ".transcriptionstreamevents",
    "TranscriptionStreamEventsTypedDict": ".transcriptionstreamevents",
    "UnknownTranscriptionStreamEventsData": ".transcriptionstreamevents",
    "TranscriptionStreamEventTypes": ".transcriptionstreameventtypes",
    "TranscriptionStreamLanguage": ".transcriptionstreamlanguage",
    "TranscriptionStreamLanguageTypedDict": ".transcriptionstreamlanguage",
    "TranscriptionStreamSegmentDelta": ".transcriptionstreamsegmentdelta",
    "TranscriptionStreamSegmentDeltaTypedDict": ".transcriptionstreamsegmentdelta",
    "TranscriptionStreamTextDelta": ".transcriptionstreamtextdelta",
    "TranscriptionStreamTextDeltaTypedDict": ".transcriptionstreamtextdelta",
    "UnarchiveModelResponse": ".unarchivemodelresponse",
    "UnarchiveModelResponseTypedDict": ".unarchivemodelresponse",
    "UpdateAgentRequest": ".updateagentrequest",
    "UpdateAgentRequestTool": ".updateagentrequest",
    "UpdateAgentRequestToolTypedDict": ".updateagentrequest",
    "UpdateAgentRequestTypedDict": ".updateagentrequest",
    "Attributes": ".updatedocumentrequest",
    "AttributesTypedDict": ".updatedocumentrequest",
    "UpdateDocumentRequest": ".updatedocumentrequest",
    "UpdateDocumentRequestTypedDict": ".updatedocumentrequest",
    "UpdateLibraryRequest": ".updatelibraryrequest",
    "UpdateLibraryRequestTypedDict": ".updatelibraryrequest",
    "UpdateModelRequest": ".updatemodelrequest",
    "UpdateModelRequestTypedDict": ".updatemodelrequest",
    "UsageInfo": ".usageinfo",
    "UsageInfoTypedDict": ".usageinfo",
    "UserMessage": ".usermessage",
    "UserMessageContent": ".usermessage",
    "UserMessageContentTypedDict": ".usermessage",
    "UserMessageTypedDict": ".usermessage",
    "Loc": ".validationerror",
    "LocTypedDict": ".validationerror",
    "ValidationError": ".validationerror",
    "ValidationErrorTypedDict": ".validationerror",
    "WandbIntegration": ".wandbintegration",
    "WandbIntegrationTypedDict": ".wandbintegration",
    "WandbIntegrationResult": ".wandbintegrationresult",
    "WandbIntegrationResultTypedDict": ".wandbintegrationresult",
    "WebSearchPremiumTool": ".websearchpremiumtool",
    "WebSearchPremiumToolTypedDict": ".websearchpremiumtool",
    "WebSearchTool": ".websearchtool",
    "WebSearchToolTypedDict": ".websearchtool",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2fdfc881ca56

from __future__ import annotations
from .ocrpageobject import OCRPageObject, OCRPageObjectTypedDict
from .ocrusageinfo import OCRUsageInfo, OCRUsageInfoTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class OCRResponseTypedDict(TypedDict):
    pages: List[OCRPageObjectTypedDict]
    r"""List of OCR info for pages."""
    model: str
    r"""The model used to generate the OCR."""
    usage_info: OCRUsageInfoTypedDict
    document_annotation: NotRequired[Nullable[str]]
    r"""Formatted response in the request_format if provided in json str"""


class OCRResponse(BaseModel):
    pages: List[OCRPageObject]
    r"""List of OCR info for pages."""

    model: str
    r"""The model used to generate the OCR."""

    usage_info: OCRUsageInfo

    document_annotation: OptionalNullable[str] = UNSET
    r"""Formatted response in the request_format if provided in json str"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["document_annotation"])
        nullable_fields = set(["document_annotation"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ee708a7ccdad

from __future__ import annotations
from .sharingout import SharingOut, SharingOutTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListSharingOutTypedDict(TypedDict):
    data: List[SharingOutTypedDict]


class ListSharingOut(BaseModel):
    data: List[SharingOut]
